!    
!      +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
!      
!      Programm fuer Berechnung der Extremwertuebertreffungen sowie Simulation von Zeitreihen
!      und Berechnung der Konfidenzbaender der simulierten Extremwertuebertreffungen
!      
!      +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
!      
!      fuer teagliche Werte von Klimadaten
!      z.B. Tmin, Tmax, RR
        
!
!===================================================================================================
!          Hier stehen die festen Werte.
 module parameters
        use nrtype
        integer, parameter  :: ndays=365                !Anzahl der Tage im Jahr
        integer, parameter  :: seventhree=73		!Laenge einer 'Jahreszeit' in Tagen
        integer, parameter  :: a_j1=1
        integer, parameter  :: a_f1=60
        integer, parameter  :: a_s1=152
        integer, parameter  :: a_s2=121
        integer, parameter  :: a_h1=244
        integer, parameter  :: a_w1=1
        integer, parameter  :: a_w2=1
        integer, parameter  :: b_j1=365
        integer, parameter  :: b_f1=151
        integer, parameter  :: b_s1=243
        integer, parameter  :: b_s2=273
        integer, parameter  :: b_h1=334
        integer, parameter  :: b_w1=59
        integer, parameter  :: b_w2=90
        integer, parameter  :: c_w1=335
        integer, parameter  :: c_w2=304
        integer, parameter  :: d_w1=365
        integer, parameter  :: d_w2=365
        integer, parameter  :: a_1=1
        integer, parameter  :: b_1=73
        integer, parameter  :: a_2=74
        integer, parameter  :: b_2=146
        integer, parameter  :: a_3=147
        integer, parameter  :: b_3=219
        integer, parameter  :: a_4=220
        integer, parameter  :: b_4=292
        integer, parameter  :: a_5=293
        integer, parameter  :: b_5=365                        
        
        real(sp), parameter     :: null  =   0.0_sp       !zum Nullen von Variablen
        real(sp), parameter     :: big   =1000.0_sp       !zum Zuruecksetzen von Variablen
        real(sp), parameter	:: one	 =   1.0_sp
        real(sp), parameter	:: half  =   0.5_sp
        real(sp), parameter	:: signifikanz = 0.10_sp

 end module parameters
!
!===================================================================================================
!         Hier werden die verwendeten Variablen definiert.
 module variablen
      use nrtype
      use parameters, only: ndays
      implicit none

      real(sp), allocatable, dimension(:,:) :: matrixtnn	!Tages-Tiefsttemperaturen im Hauptprogramm
      real(sp), allocatable, dimension(:,:) :: matrixtxx 	!Tages-Hoechsttemperaturen im Hauptprogramm
      real(sp), allocatable, dimension(:,:) :: matrixrr  	!Tages-Niederschlag im Hauptprogramm

      real(sp), allocatable, dimension(:) :: sumtnnmin        	!Summe der ExUebertreffung im Hauptprogramm
      real(sp), allocatable, dimension(:) :: sumtnnmax		!Summe der ExUebertreffung im Hauptprogramm
      real(sp), allocatable, dimension(:) :: sumtxxmin        	!Summe der ExUebertreffung im Hauptprogramm
      real(sp), allocatable, dimension(:) :: sumtxxmax        	!Summe der ExUebertreffung im Hauptprogramm
      real(sp), allocatable, dimension(:) :: sumrrmax         	!Summe der ExUebertreffung im Hauptprogramm

      real(sp), allocatable, dimension(:) :: anzahltnnmin     	!Anzahl der ExUebertreffung im Hauptprogramm
      real(sp), allocatable, dimension(:) :: anzahltnnmax     	!Anzahl der ExUebertreffung im Hauptprogramm
      real(sp), allocatable, dimension(:) :: anzahltxxmin     	!Anzahl der ExUebertreffung im Hauptprogramm
      real(sp), allocatable, dimension(:) :: anzahltxxmax     	!Anzahl der ExUebertreffung im Hauptprogramm
      real(sp), allocatable, dimension(:) :: anzahlrrmax      	!Anzahl der ExUebertreffung im Hauptprogramm
      
      real(sp), allocatable, dimension(:) :: produkttnnmin     	!Produkt der ExUebertreffung im Hauptprogramm
      real(sp), allocatable, dimension(:) :: produkttnnmax     	!Produkt der ExUebertreffung im Hauptprogramm
      real(sp), allocatable, dimension(:) :: produkttxxmin     	!Produkt der ExUebertreffung im Hauptprogramm
      real(sp), allocatable, dimension(:) :: produkttxxmax     	!Produkt der ExUebertreffung im Hauptprogramm
      real(sp), allocatable, dimension(:) :: produktrrmax      	!Produkt der ExUebertreffung im Hauptprogramm

      character(len=2)    :: abfrage                       !fuer Abfrage des Summierungszeitraumes
      character(len=1)    :: abfrage_block		   !fuer Abfrage der Blocklaenge
      character(len=100)  :: abfrage_datei1		   !fuer Abfrage des 1. Dateinamens
      character(len=100)  :: abfrage_datei2		   !fuer Abfrage des 2. Dateinamens			
      character(len=100)  :: abfrage_datei3		   !fuer Abfrage des 3. Dateinamens
      character(len=1)    :: abfrage_weitere1		   !fuer Abfrage des 2. Dateinamens	
      character(len=1)    :: abfrage_weitere2		   !fuer Abfrage des 3. Dateinamens
      character(len=17)	  :: zeitraum
      integer :: nyears
       
    
      real(sp) :: z1=-999.0_sp                          !Zufallszahl fuer Temperatur
      real(sp) :: z9=-999.0_sp				!Zufallszahl fuer Niederschlag
           
      real(sp) :: clevel
      
      integer :: n_sim 					!Anzahl der Simulationen
      real(sp), allocatable, dimension(:) :: jahr   
      integer :: l_block				!Einheitsblocklaenge in Tagen
      integer :: anfangsjahr

      
         
 end module variablen
!
!===================================================================================================
!	Definition der simulierten Variablen.

 module sim
        use nrtype
        use variablen
        use parameters

	real(sp), allocatable, dimension(:,:) :: sum1_sim  !Simulierte Summen fuer TNNmin
	real(sp), allocatable, dimension(:,:) :: sum2_sim  !		*
	real(sp), allocatable, dimension(:,:) :: sum3_sim  !		*
	real(sp), allocatable, dimension(:,:) :: sum4_sim  !		*
	real(sp), allocatable, dimension(:,:) :: sum5_sim  !		*
	       
        real(sp), allocatable, dimension(:,:) :: anz1_sim  !Simulierte Anzahlen fuer TNNmin	
        real(sp), allocatable, dimension(:,:) :: anz2_sim  !		*
        real(sp), allocatable, dimension(:,:) :: anz3_sim  !		*
        real(sp), allocatable, dimension(:,:) :: anz4_sim  !		*
        real(sp), allocatable, dimension(:,:) :: anz5_sim  !		*
        
        real(sp), allocatable, dimension(:,:) :: pro1_sim  !Simulierte Produkte fuer TNNmin	
        real(sp), allocatable, dimension(:,:) :: pro2_sim  !		*
        real(sp), allocatable, dimension(:,:) :: pro3_sim  !		*
        real(sp), allocatable, dimension(:,:) :: pro4_sim  !		*
        real(sp), allocatable, dimension(:,:) :: pro5_sim  !		*
        
        
        real(sp), allocatable, dimension(:,:) :: r_tn_resample_1_neu !Residuen nach Anwendung von bootstrap
        real(sp), allocatable, dimension(:,:) :: r_tx_resample_1_neu
        real(sp), allocatable, dimension(:,:) :: r_rr_resample_1_neu
        real(sp), allocatable, dimension(:,:) :: r_tn_resample_2_neu
        real(sp), allocatable, dimension(:,:) :: r_tx_resample_2_neu
        real(sp), allocatable, dimension(:,:) :: r_rr_resample_2_neu
        real(sp), allocatable, dimension(:,:) :: r_tn_resample_3_neu
        real(sp), allocatable, dimension(:,:) :: r_tx_resample_3_neu
        real(sp), allocatable, dimension(:,:) :: r_rr_resample_3_neu
        real(sp), allocatable, dimension(:,:) :: r_tn_resample_4_neu
        real(sp), allocatable, dimension(:,:) :: r_tx_resample_4_neu
        real(sp), allocatable, dimension(:,:) :: r_rr_resample_4_neu
        real(sp), allocatable, dimension(:,:) :: r_tn_resample_5_neu
        real(sp), allocatable, dimension(:,:) :: r_tx_resample_5_neu
        real(sp), allocatable, dimension(:,:) :: r_rr_resample_5_neu

 end module sim
!
!===================================================================================================
!	Definition der Variablen fuer die Regressionsgeraden und andere statist. Parameter.

 module stats
        use nrtype
        use variablen
        use parameters

	real(sp), dimension(1:ndays) :: a_fit_tnn	!Regressionsparameter a
	real(sp), dimension(1:ndays) :: b_fit_tnn	!Regressionsparameter b
	real(sp), dimension(1:ndays) :: siga_tnn
	real(sp), dimension(1:ndays) :: sigb_tnn
	
	real(sp), dimension(1:ndays) :: a_fit_txx
	real(sp), dimension(1:ndays) :: b_fit_txx
	real(sp), dimension(1:ndays) :: siga_txx
	real(sp), dimension(1:ndays) :: sigb_txx
	
	real(sp), dimension(1:ndays) :: a_fit_rr
	real(sp), dimension(1:ndays) :: b_fit_rr
	real(sp), dimension(1:ndays) :: siga_rr
	real(sp), dimension(1:ndays) :: sigb_rr
	
	real(sp), allocatable, dimension(:,:) :: e_tnn	!nicht normierte Residuen
	real(sp), allocatable, dimension(:,:) :: e_txx
	real(sp), allocatable, dimension(:,:) :: e_rr	
			
	real(sp), dimension(1:ndays) :: stabwtnne	!Stabw von e fuer tnn
        real(sp), dimension(1:ndays) :: stabwtxxe	!Stabw von e fuer txx
        real(sp), dimension(1:ndays) :: stabwrre	!Stabw von e fuer rr        
        real(sp), dimension(1:ndays) :: sum_vtne
        real(sp), dimension(1:ndays) :: sum_vtxe
        real(sp), dimension(1:ndays) :: sum_vrre
        
        real(sp), dimension(1:ndays) :: tnn_mittel             !Variablen zur Berechnung der Tagesmittel
      	real(sp), dimension(1:ndays) :: txx_mittel
      	real(sp), dimension(1:ndays) :: rr_mittel
      	real(sp), dimension(1:ndays) :: vtnnn                  !Variablen zur Berechnung der Varianz
      	real(sp), dimension(1:ndays) :: vtxxx
      	real(sp), dimension(1:ndays) :: vrrr
        
        real(sp), allocatable, dimension(:,:) :: r_tnn	!normierte Residuen
        real(sp), allocatable, dimension(:,:) :: r_txx
        real(sp), allocatable, dimension(:,:) :: r_rr
                
        real(sp) :: a_markov_tnn_1			!Markovkoeffizienten 
        real(sp) :: a_markov_txx_1
        real(sp) :: a_markov_rr_1	
        real(sp) :: a_markov_tnn_2
        real(sp) :: a_markov_txx_2
        real(sp) :: a_markov_rr_2	
        real(sp) :: a_markov_tnn_3
        real(sp) :: a_markov_txx_3
        real(sp) :: a_markov_rr_3	
        real(sp) :: a_markov_tnn_4
        real(sp) :: a_markov_txx_4
        real(sp) :: a_markov_rr_4	
        real(sp) :: a_markov_tnn_5
        real(sp) :: a_markov_txx_5
        real(sp) :: a_markov_rr_5
        		
 end module stats 
!
!===================================================================================================
!	Definition der Variablen fuer die Bootstrapparameter
 module boot
 	use nrtype
 	use variablen
 	use parameters  
 		
 	integer :: l_mbb_tnn_1					!autom. berechnete Blocklaengen	
        integer :: l_mbb_txx_1
        integer :: l_mbb_rr_1
        integer :: l_mbb_tnn_2
        integer :: l_mbb_txx_2
        integer :: l_mbb_rr_2
        integer :: l_mbb_tnn_3
        integer :: l_mbb_txx_3
        integer :: l_mbb_rr_3
        integer :: l_mbb_tnn_4
        integer :: l_mbb_txx_4
        integer :: l_mbb_rr_4
        integer :: l_mbb_tnn_5
        integer :: l_mbb_txx_5
        integer :: l_mbb_rr_5        
        
        real(sp), allocatable, dimension(:,:) :: r_tnn_1	!Residuen fuer jede Variable und 'Jahreszeit'
        real(sp), allocatable, dimension(:,:) :: r_txx_1
        real(sp), allocatable, dimension(:,:) :: r_rr_1
        real(sp), allocatable, dimension(:,:) :: r_tnn_2
        real(sp), allocatable, dimension(:,:) :: r_txx_2
        real(sp), allocatable, dimension(:,:) :: r_rr_2
        real(sp), allocatable, dimension(:,:) :: r_tnn_3
        real(sp), allocatable, dimension(:,:) :: r_txx_3
        real(sp), allocatable, dimension(:,:) :: r_rr_3
        real(sp), allocatable, dimension(:,:) :: r_tnn_4
        real(sp), allocatable, dimension(:,:) :: r_txx_4
        real(sp), allocatable, dimension(:,:) :: r_rr_4
        real(sp), allocatable, dimension(:,:) :: r_tnn_5
        real(sp), allocatable, dimension(:,:) :: r_txx_5
        real(sp), allocatable, dimension(:,:) :: r_rr_5
        
        real(sp), allocatable, dimension(:,:) :: r_tn_resample_1 !Residuen fuer jede Variable und 'Jahreszeit'...
        real(sp), allocatable, dimension(:,:) :: r_tx_resample_1 !...nach der Anwendung von bootstrap
        real(sp), allocatable, dimension(:,:) :: r_rr_resample_1
        real(sp), allocatable, dimension(:,:) :: r_tn_resample_2
        real(sp), allocatable, dimension(:,:) :: r_tx_resample_2
        real(sp), allocatable, dimension(:,:) :: r_rr_resample_2
        real(sp), allocatable, dimension(:,:) :: r_tn_resample_3
        real(sp), allocatable, dimension(:,:) :: r_tx_resample_3
        real(sp), allocatable, dimension(:,:) :: r_rr_resample_3
        real(sp), allocatable, dimension(:,:) :: r_tn_resample_4
        real(sp), allocatable, dimension(:,:) :: r_tx_resample_4
        real(sp), allocatable, dimension(:,:) :: r_rr_resample_4
        real(sp), allocatable, dimension(:,:) :: r_tn_resample_5
        real(sp), allocatable, dimension(:,:) :: r_tx_resample_5
        real(sp), allocatable, dimension(:,:) :: r_rr_resample_5

        real(sp) :: a_book_tnn_1				!Hilfsvariablen fuer Blocklaenge
        real(sp) :: a_book_txx_1
        real(sp) :: a_book_rr_1
        real(sp) :: a_book_tnn_2
        real(sp) :: a_book_txx_2
        real(sp) :: a_book_rr_2
        real(sp) :: a_book_tnn_3
        real(sp) :: a_book_txx_3
        real(sp) :: a_book_rr_3
        real(sp) :: a_book_tnn_4
        real(sp) :: a_book_txx_4
        real(sp) :: a_book_rr_4
        real(sp) :: a_book_tnn_5
        real(sp) :: a_book_txx_5
        real(sp) :: a_book_rr_5        
        real(sp) :: dumr2_tnn
        real(sp) :: dumr2_txx
        real(sp) :: dumr2_rr        
        real(sp) :: dumr3_tnn
        real(sp) :: dumr3_txx
        real(sp) :: dumr3_rr
        real(sp) :: dumr4_tnn
        real(sp) :: dumr4_txx
        real(sp) :: dumr4_rr
        
        real(sp), allocatable, dimension(:) :: r_tnn_neu_1	!Hilfsvariablen fuer Residuen
        real(sp), allocatable, dimension(:) :: r_txx_neu_1
        real(sp), allocatable, dimension(:) :: r_rr_neu_1
        real(sp), allocatable, dimension(:) :: r_tnn_neu_2
        real(sp), allocatable, dimension(:) :: r_txx_neu_2
        real(sp), allocatable, dimension(:) :: r_rr_neu_2
        real(sp), allocatable, dimension(:) :: r_tnn_neu_3
        real(sp), allocatable, dimension(:) :: r_txx_neu_3
        real(sp), allocatable, dimension(:) :: r_rr_neu_3
        real(sp), allocatable, dimension(:) :: r_tnn_neu_4
        real(sp), allocatable, dimension(:) :: r_txx_neu_4
        real(sp), allocatable, dimension(:) :: r_rr_neu_4
        real(sp), allocatable, dimension(:) :: r_tnn_neu_5
        real(sp), allocatable, dimension(:) :: r_txx_neu_5
        real(sp), allocatable, dimension(:) :: r_rr_neu_5
end module boot
 
!===================================================================================================
!      Hier beginnt das Hauptprogramm.
!===================================================================================================

      program extremwertuebertreffung
      use parameters
      use variablen
      use nrtype
      use sim
      implicit none
      integer i

!     1. Start und Abfrage der Berechnungsparameter.
     
      call start
      
      call ranseed  	!fuer die Berechnung der Zufallszahlen      
  
!     2. Einlesen der Klimadaten.

      call read_klimadatei
            
!     3. Berechnung der Extremwertuebertreffungen (Summe,Anzahl,Produkt)

      call solve(matrixtnn,matrixtxx,matrixrr,sumtnnmin,sumtnnmax,             &
                 sumtxxmin,sumtxxmax,sumrrmax,anzahltnnmin,anzahltnnmax,       &
                 anzahltxxmin,anzahltxxmax,anzahlrrmax,produkttnnmin,	       &	
                 produkttnnmax,produkttxxmin,produkttxxmax,produktrrmax,       &	
                 nyears,ndays)
      
!     4. Berechnung von Mittelwert und Varianz der Temp.- und Niederschlagswerte
!	 sowie Markovkoeffizienten und Blocklngen
		
      call statistik
	
!     5. Bestimmung von 'bootstrap-resampelten' Daten und Erzeugung von 
!	 simulierten Summen, Anzahlen und Produkten von Extremwertuebertreffungen
	
      call simulate            
      
!     6. Berechnung der Konfidenzbaender der simulierten Summen, Anzahlen und Produkte
!	 und Ausgabe der Daten in Dateien

      call confidence     
      
!     7. Plotten der Daten mit Gnuplot [optional]

      call plotgnu 
      
!     8. Speicherplatzfreigabe

      call deallocate            
            
      print '(a)','Fertig!'

      end program extremwertuebertreffung

!===================================================================================================
!	Subroutine zur Berechnung der Blocklaenge
subroutine blocklaenge
	use nrtype
	use stats
	use boot
	use parameters
	use variablen
	implicit none
	
	 a_book_tnn_1=a_markov_tnn_1
         dumr2_tnn=6.0**0.5*a_book_tnn_1
         dumr3_tnn=(1.0-a_book_tnn_1**2.0)
         dumr4_tnn=(dumr2_tnn/dumr3_tnn)**0.66666666666666666666666666666666666666         
         l_mbb_tnn_1=nint(dumr4_tnn*(seventhree)**0.33333333333333333333333333333333333333)
         l_mbb_tnn_1=max(1,l_mbb_tnn_1)
         l_mbb_tnn_1=min(seventhree-1,l_mbb_tnn_1)  
         a_book_txx_1=a_markov_txx_1         
         dumr2_txx=6.0**0.5*a_book_txx_1
         dumr3_txx=(1.0-a_book_txx_1**2.0)
         dumr4_txx=(dumr2_txx/dumr3_txx)**0.66666666666666666666666666666666666666         
         l_mbb_txx_1=nint(dumr4_txx*(seventhree)**0.33333333333333333333333333333333333333)
         l_mbb_txx_1=max(1,l_mbb_txx_1)         
         l_mbb_txx_1=min(seventhree-1,l_mbb_txx_1)
         a_book_rr_1=a_markov_rr_1
         dumr2_rr=6.0**0.5*a_book_rr_1
         dumr3_rr=(1.0-a_book_rr_1**2.0)
         dumr4_rr=(dumr2_rr/dumr3_rr)**0.66666666666666666666666666666666666666         
         l_mbb_rr_1=nint(dumr4_rr*(seventhree)**0.33333333333333333333333333333333333333)
         l_mbb_rr_1=max(1,l_mbb_rr_1)         
         l_mbb_rr_1=min(seventhree-1,l_mbb_rr_1)
         
         a_book_tnn_2=a_markov_tnn_2
         dumr2_tnn=6.0**0.5*a_book_tnn_2
         dumr3_tnn=(1.0-a_book_tnn_2**2.0)
         dumr4_tnn=(dumr2_tnn/dumr3_tnn)**0.66666666666666666666666666666666666666         
         l_mbb_tnn_2=nint(dumr4_tnn*(seventhree)**0.33333333333333333333333333333333333333)
         l_mbb_tnn_2=max(1,l_mbb_tnn_2)         
         l_mbb_tnn_2=min(seventhree-1,l_mbb_tnn_2)  
         a_book_txx_2=a_markov_txx_2         
         dumr2_txx=6.0**0.5*a_book_txx_2
         dumr3_txx=(1.0-a_book_txx_2**2.0)
         dumr4_txx=(dumr2_txx/dumr3_txx)**0.66666666666666666666666666666666666666         
         l_mbb_txx_2=nint(dumr4_txx*(seventhree)**0.33333333333333333333333333333333333333)
         l_mbb_txx_2=max(1,l_mbb_txx_2)         
         l_mbb_txx_2=min(seventhree-1,l_mbb_txx_2)
         a_book_rr_2=a_markov_rr_2
         dumr2_rr=6.0**0.5*a_book_rr_2
         dumr3_rr=(1.0-a_book_rr_2**2.0)
         dumr4_rr=(dumr2_rr/dumr3_rr)**0.66666666666666666666666666666666666666         
         l_mbb_rr_2=nint(dumr4_rr*(seventhree)**0.33333333333333333333333333333333333333)
         l_mbb_rr_2=max(1,l_mbb_rr_2)         
         l_mbb_rr_2=min(seventhree-1,l_mbb_rr_2)
         
         a_book_tnn_3=a_markov_tnn_3
         dumr2_tnn=6.0**0.5*a_book_tnn_3
         dumr3_tnn=(1.0-a_book_tnn_3**2.0)
         dumr4_tnn=(dumr2_tnn/dumr3_tnn)**0.66666666666666666666666666666666666666         
         l_mbb_tnn_3=nint(dumr4_tnn*(seventhree)**0.33333333333333333333333333333333333333)
         l_mbb_tnn_3=max(1,l_mbb_tnn_3)          
         l_mbb_tnn_3=min(seventhree-1,l_mbb_tnn_3) 
         a_book_txx_3=a_markov_txx_3         
         dumr2_txx=6.0**0.5*a_book_txx_3
         dumr3_txx=(1.0-a_book_txx_3**2.0)
         dumr4_txx=(dumr2_txx/dumr3_txx)**0.66666666666666666666666666666666666666         
         l_mbb_txx_3=nint(dumr4_txx*(seventhree)**0.33333333333333333333333333333333333333)
         l_mbb_txx_3=max(1,l_mbb_txx_3)         
         l_mbb_txx_3=min(seventhree-1,l_mbb_txx_3)
         a_book_rr_3=a_markov_rr_3
         dumr2_rr=6.0**0.5*a_book_rr_3
         dumr3_rr=(1.0-a_book_rr_3**2.0)
         dumr4_rr=(dumr2_rr/dumr3_rr)**0.66666666666666666666666666666666666666         
         l_mbb_rr_3=nint(dumr4_rr*(seventhree)**0.33333333333333333333333333333333333333)
         l_mbb_rr_3=max(1,l_mbb_rr_3)         
         l_mbb_rr_3=min(seventhree-1,l_mbb_rr_3)
         
         a_book_tnn_4=a_markov_tnn_4
         dumr2_tnn=6.0**0.5*a_book_tnn_4
         dumr3_tnn=(1.0-a_book_tnn_4**2.0)
         dumr4_tnn=(dumr2_tnn/dumr3_tnn)**0.66666666666666666666666666666666666666         
         l_mbb_tnn_4=nint(dumr4_tnn*(seventhree)**0.33333333333333333333333333333333333333)
         l_mbb_tnn_4=max(1,l_mbb_tnn_4)         
         l_mbb_tnn_4=min(seventhree-1,l_mbb_tnn_4)   
         a_book_txx_4=a_markov_txx_4         
         dumr2_txx=6.0**0.5*a_book_txx_4
         dumr3_txx=(1.0-a_book_txx_4**2.0)
         dumr4_txx=(dumr2_txx/dumr3_txx)**0.66666666666666666666666666666666666666         
         l_mbb_txx_4=nint(dumr4_txx*(seventhree)**0.33333333333333333333333333333333333333)
         l_mbb_txx_4=max(1,l_mbb_txx_4)         
         l_mbb_txx_4=min(seventhree-1,l_mbb_txx_4)
         a_book_rr_4=a_markov_rr_4
         dumr2_rr=6.0**0.5*a_book_rr_4
         dumr3_rr=(1.0-a_book_rr_4**2.0)
         dumr4_rr=(dumr2_rr/dumr3_rr)**0.66666666666666666666666666666666666666         
         l_mbb_rr_4=nint(dumr4_rr*(seventhree)**0.33333333333333333333333333333333333333)
         l_mbb_rr_4=max(1,l_mbb_rr_4)         
         l_mbb_rr_4=min(seventhree-1,l_mbb_rr_4)
         
         a_book_tnn_5=a_markov_tnn_5
         dumr2_tnn=6.0**0.5*a_book_tnn_5
         dumr3_tnn=(1.0-a_book_tnn_5**2.0)
         dumr4_tnn=(dumr2_tnn/dumr3_tnn)**0.66666666666666666666666666666666666666         
         l_mbb_tnn_5=nint(dumr4_tnn*(seventhree)**0.33333333333333333333333333333333333333)
         l_mbb_tnn_5=max(1,l_mbb_tnn_5)         
         l_mbb_tnn_5=min(seventhree-1,l_mbb_tnn_5)  
         a_book_txx_5=a_markov_txx_5         
         dumr2_txx=6.0**0.5*a_book_txx_5
         dumr3_txx=(1.0-a_book_txx_5**2.0)
         dumr4_txx=(dumr2_txx/dumr3_txx)**0.66666666666666666666666666666666666666         
         l_mbb_txx_5=nint(dumr4_txx*(seventhree)**0.33333333333333333333333333333333333333)
         l_mbb_txx_5=max(1,l_mbb_txx_5)         
         l_mbb_txx_5=min(seventhree-1,l_mbb_txx_5)
         a_book_rr_5=a_markov_rr_5
         dumr2_rr=6.0**0.5*a_book_rr_5
         dumr3_rr=(1.0-a_book_rr_5**2.0)
         dumr4_rr=(dumr2_rr/dumr3_rr)**0.66666666666666666666666666666666666666         
         l_mbb_rr_5=nint(dumr4_rr*(seventhree)**0.33333333333333333333333333333333333333)
         l_mbb_rr_5=max(1,l_mbb_rr_5)         
         l_mbb_rr_5=min(seventhree-1,l_mbb_rr_5)    
       
end subroutine blocklaenge
! ======================================================================
!     Berechnung des Moving Block Bootstrap (MBB) fuer e(i,j) bzw. r(i,j)
subroutine bootm(e,n,l_mbb,esim_matrix)
        use nrtype
        use nr, only:ran
        use parameters 
        use variablen        
         
        implicit none
	real(sp), dimension(n), intent(in) :: e		!Residuen (Vektor)
	integer, intent(in) :: n			!Anzahl der Daten
	integer, intent(in) :: l_mbb			!Blocklaenge
        real(sp), dimension(1:nyears,1:seventhree), intent(out) :: esim_matrix  ! resampelte Residuen (Matrix)
        
      	real(sp), dimension(n) :: esim			  	  !resampelte Residuen in der Subroutine (Vektor)
      	logical, dimension(1:seventhree,1:nyears) :: maske 	  !Maskenmatrix fuer unpack (selbe Dimension wie esim_matrix)
      	real(sp), dimension(1:seventhree,1:nyears) :: esm
      	integer, dimension(n) ::  indxx
      	integer :: idum=1
      	real(sp) :: r7						 
      
      	integer i,j,k
      	integer nbs
!      	open(8,file='ausgabe.txt')	

      	nbs=n-l_mbb+1
      
      	if (l_mbb.eq.1) then
           do i=1,n
              r7=ran(idum)				                       	
              indxx(i)=int(n*r7)+1
           end do
      	else
           k=1
outer:     do i=1,n
              r7=ran(idum)				      	
              indxx(k)=int(nbs*r7)+1
              k=k+1
              if (k.gt.n) exit outer
              do j=1,l_mbb-1
                 indxx(k)=indxx(k-1)+1
                 k=k+1
                 if (k.gt.n) exit outer
              end do
           end do outer
        end if
      
      do i=1,n					
          esim(i)=e(indxx(i))    	
      end do

      maske=.true.            			
      esm=unpack(esim,maske,esm)			!sim. Residuenvektor ---> sim. Residuenmatrix     
      esim_matrix=transpose(esm)			!transponieren von esm
      
!       write(8,'(113(f5.1,1x))') esim_matrix
!      close(8)

      return      

end subroutine bootm
!===================================================================================================
!	     subroutine zur Berechnung des xx%-Konfidenzbandes der simulierten Summen und Anzahlen

subroutine confidence
	use nrtype
	use nr, only:sort
	use parameters, only:ndays,one,half
	use variablen
      	use sim
      	use boot
      	implicit none
      	
      	real(sp), dimension(1:nyears) :: sum1_sim_upp	!oberes Konfidenzband sumtnnmin
      	real(sp), dimension(1:nyears) :: sum2_sim_upp	!oberes Konfidenzband sumtnnmax
      	real(sp), dimension(1:nyears) :: sum3_sim_upp	!oberes Konfidenzband sumtxxmin
      	real(sp), dimension(1:nyears) :: sum4_sim_upp	!oberes Konfidenzband sumtxxmax
      	real(sp), dimension(1:nyears) :: sum5_sim_upp	!oberes Konfidenzband sumrrmax      	      	
      	real(sp), dimension(1:nyears) :: sum1_sim_low	!unteres Konfidenzband sumtnnmin
      	real(sp), dimension(1:nyears) :: sum2_sim_low	!unteres Konfidenzband sumtnnmax
      	real(sp), dimension(1:nyears) :: sum3_sim_low	!unteres Konfidenzband sumtxxmin
      	real(sp), dimension(1:nyears) :: sum4_sim_low	!unteres Konfidenzband sumtxxmax
      	real(sp), dimension(1:nyears) :: sum5_sim_low	!unteres Konfidenzband sumrrmax      	     	
      	real(sp), dimension(1:nyears) :: anz1_sim_upp	!oberes Konfidenzband anztnnmin
      	real(sp), dimension(1:nyears) :: anz2_sim_upp	!oberes Konfidenzband anztnnmax
      	real(sp), dimension(1:nyears) :: anz3_sim_upp	!oberes Konfidenzband anztxxmin
      	real(sp), dimension(1:nyears) :: anz4_sim_upp	!oberes Konfidenzband anztxxmax
      	real(sp), dimension(1:nyears) :: anz5_sim_upp	!oberes Konfidenzband anzrrmax      	    	
      	real(sp), dimension(1:nyears) :: anz1_sim_low	!unteres Konfidenzband anztnnmin
      	real(sp), dimension(1:nyears) :: anz2_sim_low	!unteres Konfidenzband anztnnmax
      	real(sp), dimension(1:nyears) :: anz3_sim_low	!unteres Konfidenzband anztxxmin
      	real(sp), dimension(1:nyears) :: anz4_sim_low	!unteres Konfidenzband anztxxmax
      	real(sp), dimension(1:nyears) :: anz5_sim_low	!unteres Konfidenzband anzrrmax 
      	real(sp), dimension(1:nyears) :: pro1_sim_upp
      	real(sp), dimension(1:nyears) :: pro2_sim_upp
      	real(sp), dimension(1:nyears) :: pro3_sim_upp
      	real(sp), dimension(1:nyears) :: pro4_sim_upp
      	real(sp), dimension(1:nyears) :: pro5_sim_upp
      	real(sp), dimension(1:nyears) :: pro1_sim_low
      	real(sp), dimension(1:nyears) :: pro2_sim_low
      	real(sp), dimension(1:nyears) :: pro3_sim_low
      	real(sp), dimension(1:nyears) :: pro4_sim_low
      	real(sp), dimension(1:nyears) :: pro5_sim_low      	   	      	
      		
      	real(sp), dimension(1:nyears) :: sum1_sim_upp_90	!oberes Konfidenzband sumtnnmin
      	real(sp), dimension(1:nyears) :: sum2_sim_upp_90	!oberes Konfidenzband sumtnnmax
      	real(sp), dimension(1:nyears) :: sum3_sim_upp_90	!oberes Konfidenzband sumtxxmin
      	real(sp), dimension(1:nyears) :: sum4_sim_upp_90	!oberes Konfidenzband sumtxxmax
      	real(sp), dimension(1:nyears) :: sum5_sim_upp_90	!oberes Konfidenzband sumrrmax      	      	
      	real(sp), dimension(1:nyears) :: sum1_sim_low_90	!unteres Konfidenzband sumtnnmin
      	real(sp), dimension(1:nyears) :: sum2_sim_low_90	!unteres Konfidenzband sumtnnmax
      	real(sp), dimension(1:nyears) :: sum3_sim_low_90	!unteres Konfidenzband sumtxxmin
      	real(sp), dimension(1:nyears) :: sum4_sim_low_90	!unteres Konfidenzband sumtxxmax
      	real(sp), dimension(1:nyears) :: sum5_sim_low_90	!unteres Konfidenzband sumrrmax      	
      	real(sp), dimension(1:nyears) :: sum1_sim_upp_98	!oberes Konfidenzband sumtnnmin
      	real(sp), dimension(1:nyears) :: sum2_sim_upp_98	!oberes Konfidenzband sumtnnmax
      	real(sp), dimension(1:nyears) :: sum3_sim_upp_98	!oberes Konfidenzband sumtxxmin
      	real(sp), dimension(1:nyears) :: sum4_sim_upp_98	!oberes Konfidenzband sumtxxmax
      	real(sp), dimension(1:nyears) :: sum5_sim_upp_98	!oberes Konfidenzband sumrrmax      	      	
      	real(sp), dimension(1:nyears) :: sum1_sim_low_98	!unteres Konfidenzband sumtnnmin
      	real(sp), dimension(1:nyears) :: sum2_sim_low_98	!unteres Konfidenzband sumtnnmax
      	real(sp), dimension(1:nyears) :: sum3_sim_low_98	!unteres Konfidenzband sumtxxmin
      	real(sp), dimension(1:nyears) :: sum4_sim_low_98	!unteres Konfidenzband sumtxxmax
      	real(sp), dimension(1:nyears) :: sum5_sim_low_98	!unteres Konfidenzband sumrrmax
      	real(sp), dimension(1:nyears) :: anz1_sim_upp_90	!oberes Konfidenzband anztnnmin
      	real(sp), dimension(1:nyears) :: anz2_sim_upp_90	!oberes Konfidenzband anztnnmax
      	real(sp), dimension(1:nyears) :: anz3_sim_upp_90	!oberes Konfidenzband anztxxmin
      	real(sp), dimension(1:nyears) :: anz4_sim_upp_90	!oberes Konfidenzband anztxxmax
      	real(sp), dimension(1:nyears) :: anz5_sim_upp_90	!oberes Konfidenzband anzrrmax      	    	
      	real(sp), dimension(1:nyears) :: anz1_sim_low_90	!unteres Konfidenzband anztnnmin
      	real(sp), dimension(1:nyears) :: anz2_sim_low_90	!unteres Konfidenzband anztnnmax
      	real(sp), dimension(1:nyears) :: anz3_sim_low_90	!unteres Konfidenzband anztxxmin
      	real(sp), dimension(1:nyears) :: anz4_sim_low_90	!unteres Konfidenzband anztxxmax
      	real(sp), dimension(1:nyears) :: anz5_sim_low_90	!unteres Konfidenzband anzrrmax
      	real(sp), dimension(1:nyears) :: anz1_sim_upp_98	!oberes Konfidenzband anztnnmin
      	real(sp), dimension(1:nyears) :: anz2_sim_upp_98	!oberes Konfidenzband anztnnmax
      	real(sp), dimension(1:nyears) :: anz3_sim_upp_98	!oberes Konfidenzband anztxxmin
      	real(sp), dimension(1:nyears) :: anz4_sim_upp_98	!oberes Konfidenzband anztxxmax
      	real(sp), dimension(1:nyears) :: anz5_sim_upp_98	!oberes Konfidenzband anzrrmax      	    	
      	real(sp), dimension(1:nyears) :: anz1_sim_low_98	!unteres Konfidenzband anztnnmin
      	real(sp), dimension(1:nyears) :: anz2_sim_low_98	!unteres Konfidenzband anztnnmax
      	real(sp), dimension(1:nyears) :: anz3_sim_low_98	!unteres Konfidenzband anztxxmin
      	real(sp), dimension(1:nyears) :: anz4_sim_low_98	!unteres Konfidenzband anztxxmax
      	real(sp), dimension(1:nyears) :: anz5_sim_low_98	!unteres Konfidenzband anzrrmax 
      	real(sp), dimension(1:nyears) :: pro1_sim_upp_90
      	real(sp), dimension(1:nyears) :: pro2_sim_upp_90
      	real(sp), dimension(1:nyears) :: pro3_sim_upp_90
      	real(sp), dimension(1:nyears) :: pro4_sim_upp_90
      	real(sp), dimension(1:nyears) :: pro5_sim_upp_90
      	real(sp), dimension(1:nyears) :: pro1_sim_low_90
      	real(sp), dimension(1:nyears) :: pro2_sim_low_90
      	real(sp), dimension(1:nyears) :: pro3_sim_low_90
      	real(sp), dimension(1:nyears) :: pro4_sim_low_90
      	real(sp), dimension(1:nyears) :: pro5_sim_low_90
      	real(sp), dimension(1:nyears) :: pro1_sim_upp_98
      	real(sp), dimension(1:nyears) :: pro2_sim_upp_98
      	real(sp), dimension(1:nyears) :: pro3_sim_upp_98
      	real(sp), dimension(1:nyears) :: pro4_sim_upp_98
      	real(sp), dimension(1:nyears) :: pro5_sim_upp_98
      	real(sp), dimension(1:nyears) :: pro1_sim_low_98
      	real(sp), dimension(1:nyears) :: pro2_sim_low_98
      	real(sp), dimension(1:nyears) :: pro3_sim_low_98
      	real(sp), dimension(1:nyears) :: pro4_sim_low_98
      	real(sp), dimension(1:nyears) :: pro5_sim_low_98	      	      	      	            
      	      	
      	integer :: i                                      !Das sind die Laufvariablen     Jahre
        integer :: j                                      !fuer die do-Schleifen.         Tage
        integer :: k 					  !Anzahl der Simulationen 
        integer, allocatable, dimension(:) :: jahr_neu
        allocate (jahr_neu(1:nyears))
        									         
        write(*,'(a30)') 'Berechnung der Konf.baender...'                      
      	do i=1,nyears
      	 	call sort(sum1_sim(i,1:n_sim))		!Aufruf der Subroutine zum sortieren der simulierten Summen
      	 	call sort(sum2_sim(i,1:n_sim))
      	 	call sort(sum3_sim(i,1:n_sim))
      	 	call sort(sum4_sim(i,1:n_sim))
      	 	call sort(sum5_sim(i,1:n_sim))
      	 	
      	 	call sort(anz1_sim(i,1:n_sim))		!Aufruf der Subroutine zum sortieren der simulierten Anzahlen
      	 	call sort(anz2_sim(i,1:n_sim))
      	 	call sort(anz3_sim(i,1:n_sim))
      	 	call sort(anz4_sim(i,1:n_sim))
      	 	call sort(anz5_sim(i,1:n_sim))
      	 	
      	 	call sort(pro1_sim(i,1:n_sim))		!Aufruf der Subroutine zum sortieren der simulierten Produkte
      	 	call sort(pro2_sim(i,1:n_sim))
      	 	call sort(pro3_sim(i,1:n_sim))
      	 	call sort(pro4_sim(i,1:n_sim))
      	 	call sort(pro5_sim(i,1:n_sim))      	 		 
       	end do
       !	open(588,file='ausgabe.txt')
       !	write(588,'(114(f5.1,1x))') ((sum1_sim(i,k),i=1,nyears),k=1,n_sim)
       !	close(588)
!------------------------ Berechnung des 0.1% und 99.9% Konfidenzbandes --------------------------------------------------------      	
	do i=1,nyears
	   
	   jahr_neu(i)=anfangsjahr-1+i	
	
	   sum1_sim_upp(i)=sum1_sim(i,nint(0.999*n_sim))	!Berechnung des oberen Konfidenzbandes der Summen
	   sum2_sim_upp(i)=sum2_sim(i,nint(0.999*n_sim))
	   sum3_sim_upp(i)=sum3_sim(i,nint(0.999*n_sim))
	   sum4_sim_upp(i)=sum4_sim(i,nint(0.999*n_sim))
	   sum5_sim_upp(i)=sum5_sim(i,nint(0.999*n_sim))
 							
 	   if(n_sim.lt.600) then
 	   sum1_sim_low(i)=sum1_sim(i,1)
 	   sum2_sim_low(i)=sum2_sim(i,1)
 	   sum3_sim_low(i)=sum3_sim(i,1)
 	   sum4_sim_low(i)=sum4_sim(i,1)
 	   sum5_sim_low(i)=sum5_sim(i,1)
 	   else 	   									
	   sum1_sim_low(i)=sum1_sim(i,nint(0.001*n_sim))		!Berechnung des unteren Konfidenzbandes der Summen
           sum2_sim_low(i)=sum2_sim(i,nint(0.001*n_sim))
           sum3_sim_low(i)=sum3_sim(i,nint(0.001*n_sim))
           sum4_sim_low(i)=sum4_sim(i,nint(0.001*n_sim))
           sum5_sim_low(i)=sum5_sim(i,nint(0.001*n_sim))
           end if
                      
           anz1_sim_upp(i)=anz1_sim(i,nint(0.999*n_sim ))	!Berechnung des oberen Konfidenzbandes der Anzahlen
	   anz2_sim_upp(i)=anz2_sim(i,nint(0.999*n_sim ))
	   anz3_sim_upp(i)=anz3_sim(i,nint(0.999*n_sim ))
	   anz4_sim_upp(i)=anz4_sim(i,nint(0.999*n_sim ))
	   anz5_sim_upp(i)=anz5_sim(i,nint(0.999*n_sim ))
	   
   	   if(n_sim.lt.600) then
   	   anz1_sim_low(i)=anz1_sim(i,1)
   	   anz2_sim_low(i)=anz2_sim(i,1)
   	   anz3_sim_low(i)=anz3_sim(i,1)
   	   anz4_sim_low(i)=anz4_sim(i,1)
   	   anz5_sim_low(i)=anz5_sim(i,1)
   	   else									
	   anz1_sim_low(i)=anz1_sim(i,nint(0.001*n_sim))		!Berechnung des unteren Konfidenzbandes der Anzahlen
           anz2_sim_low(i)=anz2_sim(i,nint(0.001*n_sim))
           anz3_sim_low(i)=anz3_sim(i,nint(0.001*n_sim))
           anz4_sim_low(i)=anz4_sim(i,nint(0.001*n_sim))
           anz5_sim_low(i)=anz5_sim(i,nint(0.001*n_sim))
           end if 
           
           pro1_sim_upp(i)=pro1_sim(i,nint(0.999*n_sim ))
           pro2_sim_upp(i)=pro2_sim(i,nint(0.999*n_sim ))
           pro3_sim_upp(i)=pro3_sim(i,nint(0.999*n_sim ))
           pro4_sim_upp(i)=pro4_sim(i,nint(0.999*n_sim ))
           pro5_sim_upp(i)=pro5_sim(i,nint(0.999*n_sim ))
           
           if(n_sim.lt.600) then
           pro1_sim_low(i)=pro1_sim(i,1)
           pro2_sim_low(i)=pro1_sim(i,1)
           pro3_sim_low(i)=pro1_sim(i,1)
           pro4_sim_low(i)=pro1_sim(i,1)
           pro5_sim_low(i)=pro1_sim(i,1)
           else           
           pro1_sim_low(i)=pro1_sim(i,nint(0.001*n_sim ))
           pro2_sim_low(i)=pro2_sim(i,nint(0.001*n_sim ))
           pro3_sim_low(i)=pro3_sim(i,nint(0.001*n_sim ))
           pro4_sim_low(i)=pro4_sim(i,nint(0.001*n_sim ))
           pro5_sim_low(i)=pro5_sim(i,nint(0.001*n_sim ))
           end if
           
	end do
	
!----------------------- Berechnung des 5% und 95% Konfidenzbandes ---------------------------------------------------	
	do i=1,nyears
	
	   sum1_sim_upp_90(i)=sum1_sim(i,NINT(0.95*n_sim))	!Berechnung des oberen Konfidenzbandes der Summen
	   sum2_sim_upp_90(i)=sum2_sim(i,NINT(0.95*n_sim))
	   sum3_sim_upp_90(i)=sum3_sim(i,NINT(0.95*n_sim))
	   sum4_sim_upp_90(i)=sum4_sim(i,nint(0.95*n_sim))
	   sum5_sim_upp_90(i)=sum5_sim(i,nint(0.95*n_sim))
   	
   	   if(n_sim.lt.20) then					!Vermeidung von sum1_sim(i,0) bei...
   	   sum1_sim_low_90(i)=sum1_sim(i,1)			!...zu kleinem n_sim
   	   sum2_sim_low_90(i)=sum2_sim(i,1)
   	   sum3_sim_low_90(i)=sum3_sim(i,1)
   	   sum4_sim_low_90(i)=sum4_sim(i,1)
   	   sum5_sim_low_90(i)=sum5_sim(i,1)
   	   else								
	   sum1_sim_low_90(i)=sum1_sim(i,nint(0.05*n_sim))	!Berechnung des unteren Konfidenzbandes der Summen
           sum2_sim_low_90(i)=sum2_sim(i,nint(0.05*n_sim))
           sum3_sim_low_90(i)=sum3_sim(i,nint(0.05*n_sim))
           sum4_sim_low_90(i)=sum4_sim(i,nint(0.05*n_sim))
           sum5_sim_low_90(i)=sum5_sim(i,nint(0.05*n_sim))
           end if 
           
           anz1_sim_upp_90(i)=anz1_sim(i,nint(0.95*n_sim))	
	   anz2_sim_upp_90(i)=anz2_sim(i,nint(0.95*n_sim))
	   anz3_sim_upp_90(i)=anz3_sim(i,nint(0.95*n_sim))
	   anz4_sim_upp_90(i)=anz4_sim(i,nint(0.95*n_sim))
	   anz5_sim_upp_90(i)=anz5_sim(i,nint(0.95*n_sim))
   	
   	   if(n_sim.lt.20) then
   	   anz1_sim_low_90(i)=anz1_sim(i,1)
   	   anz2_sim_low_90(i)=anz2_sim(i,1)
   	   anz3_sim_low_90(i)=anz3_sim(i,1)
   	   anz4_sim_low_90(i)=anz4_sim(i,1)
   	   anz5_sim_low_90(i)=anz5_sim(i,1)
	   else	   	   									
	   anz1_sim_low_90(i)=anz1_sim(i,nint(0.05*n_sim))		
           anz2_sim_low_90(i)=anz2_sim(i,nint(0.05*n_sim))
           anz3_sim_low_90(i)=anz3_sim(i,nint(0.05*n_sim))
           anz4_sim_low_90(i)=anz4_sim(i,nint(0.05*n_sim))
           anz5_sim_low_90(i)=anz5_sim(i,nint(0.05*n_sim))
           end if 
           
           pro1_sim_upp_90(i)=pro1_sim(i,nint(0.95*n_sim))
           pro2_sim_upp_90(i)=pro2_sim(i,nint(0.95*n_sim))
           pro3_sim_upp_90(i)=pro3_sim(i,nint(0.95*n_sim))
           pro4_sim_upp_90(i)=pro4_sim(i,nint(0.95*n_sim))
           pro5_sim_upp_90(i)=pro5_sim(i,nint(0.95*n_sim))
           
           if(n_sim.lt.20) then
           pro1_sim_low_90(i)=pro1_sim(i,1)
           pro2_sim_low_90(i)=pro2_sim(i,1)
           pro3_sim_low_90(i)=pro3_sim(i,1)
           pro4_sim_low_90(i)=pro4_sim(i,1)
           pro5_sim_low_90(i)=pro5_sim(i,1)           
           else
           pro1_sim_low_90(i)=pro1_sim(i,nint(0.05*n_sim))
           pro2_sim_low_90(i)=pro2_sim(i,nint(0.05*n_sim))
           pro3_sim_low_90(i)=pro3_sim(i,nint(0.05*n_sim))
           pro4_sim_low_90(i)=pro4_sim(i,nint(0.05*n_sim))
           pro5_sim_low_90(i)=pro5_sim(i,nint(0.05*n_sim))
           end if
                               
	end do
	 
!---------------------- Berechnung des 1% und 99% Konfidenzbandes --------------------------------------------------------	
	do i=1,nyears
	
	   sum1_sim_upp_98(i)=sum1_sim(i,nint(0.99*n_sim ))	!Berechnung des oberen Konfidenzbandes der Summen
	   sum2_sim_upp_98(i)=sum2_sim(i,nint(0.99*n_sim ))
	   sum3_sim_upp_98(i)=sum3_sim(i,nint(0.99*n_sim ))
	   sum4_sim_upp_98(i)=sum4_sim(i,nint(0.99*n_sim ))
	   sum5_sim_upp_98(i)=sum5_sim(i,nint(0.99*n_sim ))
   	
   	   if(n_sim.lt.100) then
   	   sum1_sim_low_98(i)=sum1_sim(i,1)
   	   sum2_sim_low_98(i)=sum2_sim(i,1)
   	   sum3_sim_low_98(i)=sum3_sim(i,1)
   	   sum4_sim_low_98(i)=sum4_sim(i,1)
   	   sum5_sim_low_98(i)=sum5_sim(i,1)
	   else   	   									
	   sum1_sim_low_98(i)=sum1_sim(i,nint(0.01*n_sim))	!Berechnung des unteren Konfidenzbandes der Summen
           sum2_sim_low_98(i)=sum2_sim(i,nint(0.01*n_sim))
           sum3_sim_low_98(i)=sum3_sim(i,nint(0.01*n_sim))
           sum4_sim_low_98(i)=sum4_sim(i,nint(0.01*n_sim))
           sum5_sim_low_98(i)=sum5_sim(i,nint(0.01*n_sim))
           end if         
           
           anz1_sim_upp_98(i)=anz1_sim(i,nint(0.99*n_sim ))	
	   anz2_sim_upp_98(i)=anz2_sim(i,nint(0.99*n_sim ))
	   anz3_sim_upp_98(i)=anz3_sim(i,nint(0.99*n_sim ))
	   anz4_sim_upp_98(i)=anz4_sim(i,nint(0.99*n_sim ))
	   anz5_sim_upp_98(i)=anz5_sim(i,nint(0.99*n_sim ))
   	
   	   if(n_sim.lt.100) then
   	   anz1_sim_low_98(i)=anz1_sim(i,1)
   	   anz2_sim_low_98(i)=anz2_sim(i,1)
   	   anz3_sim_low_98(i)=anz3_sim(i,1)
   	   anz4_sim_low_98(i)=anz4_sim(i,1)
   	   anz5_sim_low_98(i)=anz5_sim(i,1)
   	   else									
	   anz1_sim_low_98(i)=anz1_sim(i,nint(0.01*n_sim))		
           anz2_sim_low_98(i)=anz2_sim(i,nint(0.01*n_sim))
           anz3_sim_low_98(i)=anz3_sim(i,nint(0.01*n_sim))
           anz4_sim_low_98(i)=anz4_sim(i,nint(0.01*n_sim))
           anz5_sim_low_98(i)=anz5_sim(i,nint(0.01*n_sim))
           end if
           
           pro1_sim_upp_98(i)=pro1_sim(i,nint(0.99*n_sim))
           pro2_sim_upp_98(i)=pro2_sim(i,nint(0.99*n_sim))
           pro3_sim_upp_98(i)=pro3_sim(i,nint(0.99*n_sim))
           pro4_sim_upp_98(i)=pro4_sim(i,nint(0.99*n_sim))
           pro5_sim_upp_98(i)=pro5_sim(i,nint(0.99*n_sim))
           
           if(n_sim.lt.100) then
           pro1_sim_low_98(i)=pro1_sim(i,1)
           pro2_sim_low_98(i)=pro2_sim(i,1)
           pro3_sim_low_98(i)=pro3_sim(i,1)
           pro4_sim_low_98(i)=pro4_sim(i,1)
           pro5_sim_low_98(i)=pro5_sim(i,1)
           else
           pro1_sim_low_98(i)=pro1_sim(i,nint(0.01*n_sim))
           pro2_sim_low_98(i)=pro2_sim(i,nint(0.01*n_sim))
           pro3_sim_low_98(i)=pro3_sim(i,nint(0.01*n_sim))
           pro4_sim_low_98(i)=pro4_sim(i,nint(0.01*n_sim))
           pro5_sim_low_98(i)=pro5_sim(i,nint(0.01*n_sim))
           end if
           					       
	end do
	   
	open(1,file='t_Ausgabe_TNNmin.txt')			!Ausgabe der Daten
	write(1,*)    'TNNmin	Konfidenzbaender'
	write(1,*)    'n_sim=',n_sim,'     Fuer Summierungszeitraum: ',zeitraum
	write(1,*)    'Blocklaengen Periode 1/2/3/4/5=',l_mbb_tnn_1,l_mbb_tnn_2,l_mbb_tnn_3,l_mbb_tnn_4,l_mbb_tnn_5
	write(1,*)    ' '	
	write(1,*)    '      Summe                                                  Anzahl  			   		             Produkt'
	write(1,*)    ' '	  
	write(1,941) (jahr_neu(i),sum1_sim_low(i),sum1_sim_low_98(i),sum1_sim_low_90(i),sum1_sim_upp_90(i),	&
		      sum1_sim_upp_98(i),sum1_sim_upp(i),sumtnnmin(i),						&
		      anz1_sim_low(i),anz1_sim_low_98(i),anz1_sim_low_90(i),anz1_sim_upp_90(i),			&
		      anz1_sim_upp_98(i),anz1_sim_upp(i),anzahltnnmin(i),					&
		      pro1_sim_low(i),pro1_sim_low_98(i),pro1_sim_low_90(i),pro1_sim_upp_90(i),			&
		      pro1_sim_upp_98(i),pro1_sim_upp(i),produkttnnmin(i),					&
		      i=1,nyears)		  
	close(1)
	
	open(2,file='t_Ausgabe_TNNmax.txt')			!Ausgabe der Daten
	write(2,*)    'TNNmax'
	write(2,*)    'n_sim=',n_sim,'     Fuer Summierungszeitraum: ',zeitraum
	write(2,*)    'Blocklaengen Periode 1/2/3/4/5=',l_mbb_tnn_1,l_mbb_tnn_2,l_mbb_tnn_3,l_mbb_tnn_4,l_mbb_tnn_5
	write(2,*)    ' '
	write(2,*)    '      Summe                                                  Anzahl  			   		             Produkt'
	write(2,*)    ' '
	write(2,941) (jahr_neu(i),sum2_sim_low(i),sum2_sim_low_98(i),sum2_sim_low_90(i),sum2_sim_upp_90(i),	&
		      sum2_sim_upp_98(i),sum2_sim_upp(i),sumtnnmax(i),						&
		      anz2_sim_low(i),anz2_sim_low_98(i),anz2_sim_low_90(i),anz2_sim_upp_90(i),			&
		      anz2_sim_upp_98(i),anz2_sim_upp(i),anzahltnnmax(i),					&
		      pro2_sim_low(i),pro2_sim_low_98(i),pro2_sim_low_90(i),pro2_sim_upp_90(i),			&
		      pro2_sim_upp_98(i),pro2_sim_upp(i),produkttnnmax(i),					&
		      i=1,nyears)
	close(2)
	
	if(abfrage_weitere1.eq.'j') then
	open(3,file='t_Ausgabe_TXXmin.txt')			!Ausgabe der Daten
	write(3,*)    'TXXmin'
	write(3,*)    'n_sim=',n_sim,'     Fuer Summierungszeitraum: ',zeitraum
	write(3,*)    'Blocklaengen Periode 1/2/3/4/5=',l_mbb_txx_1,l_mbb_txx_2,l_mbb_txx_3,l_mbb_txx_4,l_mbb_txx_5
	write(3,*)    ' '
	write(3,*)    '      Summe                                                  Anzahl  			   		             Produkt'
	write(3,*)    ' '
	write(3,941) (jahr_neu(i),sum3_sim_low(i),sum3_sim_low_98(i),sum3_sim_low_90(i),sum3_sim_upp_90(i),	&
		      sum3_sim_upp_98(i),sum3_sim_upp(i),sumtxxmin(i),						&
		      anz3_sim_low(i),anz3_sim_low_98(i),anz3_sim_low_90(i),anz3_sim_upp_90(i),			&
		      anz3_sim_upp_98(i),anz3_sim_upp(i),anzahltxxmin(i),					&
		      pro3_sim_low(i),pro3_sim_low_98(i),pro3_sim_low_90(i),pro3_sim_upp_90(i),			&
		      pro3_sim_upp_98(i),pro3_sim_upp(i),produkttxxmin(i),					&
		      i=1,nyears)
	close(3)
	
	open(4,file='t_Ausgabe_TXXmax.txt')			!Ausgabe der Daten
	write(4,*)    'TXXmax'
	write(4,*)    'n_sim=',n_sim,'     Fuer Summierungszeitraum: ',zeitraum
	write(4,*)    'Blocklaengen Periode 1/2/3/4/5=',l_mbb_txx_1,l_mbb_txx_2,l_mbb_txx_3,l_mbb_txx_4,l_mbb_txx_5
	write(4,*)    ' '
	write(4,*)    '      Summe                                                  Anzahl  			   		             Produkt'
	write(4,*)    ' '
	write(4,941) (jahr_neu(i),sum4_sim_low(i),sum4_sim_low_98(i),sum4_sim_low_90(i),sum4_sim_upp_90(i),	&
		      sum4_sim_upp_98(i),sum4_sim_upp(i),sumtxxmax(i),						&
		      anz4_sim_low(i),anz4_sim_low_98(i),anz4_sim_low_90(i),anz4_sim_upp_90(i),			&
		      anz4_sim_upp_98(i),anz4_sim_upp(i),anzahltxxmax(i),					&
		      pro4_sim_low(i),pro4_sim_low_98(i),pro4_sim_low_90(i),pro4_sim_upp_90(i),			&
		      pro4_sim_upp_98(i),pro4_sim_upp(i),produkttxxmax(i),					&
		      i=1,nyears)
	close(4)
	end if
	
	if(abfrage_weitere2.eq.'j') then              
	open(5,file='t_Ausgabe_RRmax.txt')			!Ausgabe der Daten
	write(5,*)    'RRmax'
	write(5,*)    'n_sim=',n_sim,'     Fuer Summierungszeitraum: ',zeitraum
	write(5,*)    'Blocklaengen Periode 1/2/3/4/5=',l_mbb_rr_1,l_mbb_rr_2,l_mbb_rr_3,l_mbb_rr_4,l_mbb_rr_5
	write(5,*)    ' '
	write(5,*)    '      Summe                                                  Anzahl  			   		             Produkt'
	write(5,*)    ' '
	write(5,941) (jahr_neu(i),sum5_sim_low(i),sum5_sim_low_98(i),sum5_sim_low_90(i),sum5_sim_upp_90(i),	&
		      sum5_sim_upp_98(i),sum5_sim_upp(i),sumrrmax(i),						&
		      anz5_sim_low(i),anz5_sim_low_98(i),anz5_sim_low_90(i),anz5_sim_upp_90(i),			&
		      anz5_sim_upp_98(i),anz5_sim_upp(i),anzahlrrmax(i),					&
		      pro5_sim_low(i),pro5_sim_low_98(i),pro5_sim_low_90(i),pro5_sim_upp_90(i),			&
		      pro5_sim_upp_98(i),pro5_sim_upp(i),produktrrmax(i),					&
		      i=1,nyears)
	close(5)
	end if
	
	deallocate (jahr_neu)
	
942	format(22(f7.1,1x))		
941	format(i4,1x,f7.1,1x,f7.1,1x,f7.1,1x,f7.1,1x,f7.1,1x,f7.1,1x,f7.1,1x,f7.1,1x,f7.1,1x,f7.1,1x,f7.1,1x,f7.1,1x, & !21(f7.1,1x) funktioniert nicht mit i4 zusammen
                 f7.1,1x,f7.1,1x,f7.1,1x,f7.1,1x,f7.1,1x,f7.1,1x,f7.1,1x,f7.1,1x,f7.1,1x)
 
end subroutine confidence
!===================================================================================================
!               subroutine zur Speicherplatzfreigabe

subroutine deallocate
	use variablen
	use sim
	use parameters
	use stats
	use boot
	
	deallocate (sum1_sim,sum2_sim,sum3_sim,sum4_sim,sum5_sim)
	deallocate (anz1_sim,anz2_sim,anz3_sim,anz4_sim,anz5_sim)
	deallocate (pro1_sim,pro2_sim,pro3_sim,pro4_sim,pro5_sim)
	
!----Aus Modul variablen-----------------------------------------------------
	
        deallocate(matrixtnn,matrixtxx,matrixrr)
        deallocate(sumtnnmin,sumtnnmax,sumtxxmin,sumtxxmax,sumrrmax)
        deallocate(anzahltnnmin,anzahltnnmax,anzahltxxmin,anzahltxxmax,anzahlrrmax)      
        deallocate(produkttnnmin,produkttnnmax,produkttxxmin,produkttxxmax,produktrrmax)    
        deallocate(jahr)
      
!----Aus Modul sim-----------------------------------------------------------

        deallocate(r_tn_resample_1_neu,r_tx_resample_1_neu,r_rr_resample_1_neu)
        deallocate(r_tn_resample_2_neu,r_tx_resample_2_neu,r_rr_resample_2_neu)
        deallocate(r_tn_resample_3_neu,r_tx_resample_3_neu,r_rr_resample_3_neu)
        deallocate(r_tn_resample_4_neu,r_tx_resample_4_neu,r_rr_resample_4_neu)
        deallocate(r_tn_resample_5_neu,r_tx_resample_5_neu,r_rr_resample_5_neu)
        
!----Aus Modul stats----------------------------------------------------------

	deallocate(e_tnn,e_txx,e_rr)	
	deallocate(r_tnn,r_txx,r_rr)  

!----Aus Module boot----------------------------------------------------------

        deallocate(r_tnn_1,r_txx_1,r_rr_1)
        deallocate(r_tnn_2,r_txx_2,r_rr_2)
        deallocate(r_tnn_3,r_txx_3,r_rr_3)
        deallocate(r_tnn_4,r_txx_4,r_rr_4)
        deallocate(r_tnn_5,r_txx_5,r_rr_5)
    
        deallocate(r_tn_resample_1,r_tx_resample_1,r_rr_resample_1)
        deallocate(r_tn_resample_2,r_tx_resample_2,r_rr_resample_2)
        deallocate(r_tn_resample_3,r_tx_resample_3,r_rr_resample_3)
        deallocate(r_tn_resample_4,r_tx_resample_4,r_rr_resample_4)
        deallocate(r_tn_resample_5,r_tx_resample_5,r_rr_resample_5)
                
        deallocate(r_tnn_neu_1,r_txx_neu_1,r_rr_neu_1)
        deallocate(r_tnn_neu_2,r_txx_neu_2,r_rr_neu_2)
        deallocate(r_tnn_neu_3,r_txx_neu_3,r_rr_neu_3)
        deallocate(r_tnn_neu_4,r_txx_neu_4,r_rr_neu_4)
        deallocate(r_tnn_neu_5,r_txx_neu_5,r_rr_neu_5)         
	
end subroutine deallocate

!===================================================================================================
!               Subroutine zur Berechnung der zeitl. veraenderl. Mittelwerte y=a+bx
SUBROUTINE fit(x,y,n,a,b,siga,sigb)
	USE nrtype; USE nrutil, ONLY : assert_eq
	IMPLICIT NONE
	integer, intent(in) :: n
	REAL(SP), DIMENSION(n), INTENT(IN) :: x,y
	REAL(SP), INTENT(OUT) :: a,b,siga,sigb
	REAL(SP) :: sigdat,ss,sx,sxoss,sy,st2
	REAL(SP), DIMENSION(n) :: t
	a=0.0_sp
	b=0.0_sp
		ss=real(n,sp)
		sx=sum(x)
		sy=sum(y)
	sxoss=sx/ss
	t(:)=x(:)-sxoss
		b=dot_product(t,y)
	st2=dot_product(t,t)
	b=b/st2
	a=(sy-sx*b)/ss
	siga=sqrt((1.0_sp+sx*sx/(ss*st2))/ss)
	sigb=sqrt(1.0_sp/st2)
 END SUBROUTINE fit

!===================================================================================================
!               subroutine zur Berechnung der normierten Residuen r(i,j) und des Markovkoeffizienten a
subroutine markov
	use nrtype
	use parameters
	use stats
	use boot
	implicit none
	integer :: j
	integer :: i
	integer :: k
	real(sp) :: sum_r_tnn1_1
        real(sp) :: sum_r_tnn2_1
        real(sp) :: sum_r_txx1_1
        real(sp) :: sum_r_txx2_1
        real(sp) :: sum_r_rr1_1
        real(sp) :: sum_r_rr2_1 
        real(sp) :: sum_r_tnn1_2
        real(sp) :: sum_r_tnn2_2
        real(sp) :: sum_r_txx1_2
        real(sp) :: sum_r_txx2_2
        real(sp) :: sum_r_rr1_2
        real(sp) :: sum_r_rr2_2 
        real(sp) :: sum_r_tnn1_3
        real(sp) :: sum_r_tnn2_3
        real(sp) :: sum_r_txx1_3
        real(sp) :: sum_r_txx2_3
        real(sp) :: sum_r_rr1_3
        real(sp) :: sum_r_rr2_3 
        real(sp) :: sum_r_tnn1_4
        real(sp) :: sum_r_tnn2_4
        real(sp) :: sum_r_txx1_4
        real(sp) :: sum_r_txx2_4
        real(sp) :: sum_r_rr1_4
        real(sp) :: sum_r_rr2_4 
        real(sp) :: sum_r_tnn1_5
        real(sp) :: sum_r_tnn2_5
        real(sp) :: sum_r_txx1_5
        real(sp) :: sum_r_txx2_5
        real(sp) :: sum_r_rr1_5
        real(sp) :: sum_r_rr2_5 

        real(sp), dimension(1:seventhree,1:nyears) :: r_tnn_11
        real(sp), dimension(1:seventhree,1:nyears) :: r_txx_11
        real(sp), dimension(1:seventhree,1:nyears) :: r_rr_11
        real(sp), dimension(1:seventhree,1:nyears) :: r_tnn_22
        real(sp), dimension(1:seventhree,1:nyears) :: r_txx_22
        real(sp), dimension(1:seventhree,1:nyears) :: r_rr_22
        real(sp), dimension(1:seventhree,1:nyears) :: r_tnn_33
        real(sp), dimension(1:seventhree,1:nyears) :: r_txx_33
        real(sp), dimension(1:seventhree,1:nyears) :: r_rr_33
        real(sp), dimension(1:seventhree,1:nyears) :: r_tnn_44
        real(sp), dimension(1:seventhree,1:nyears) :: r_txx_44
        real(sp), dimension(1:seventhree,1:nyears) :: r_rr_44
        real(sp), dimension(1:seventhree,1:nyears) :: r_tnn_55
        real(sp), dimension(1:seventhree,1:nyears) :: r_txx_55
        real(sp), dimension(1:seventhree,1:nyears) :: r_rr_55
        
                    
	
!Berechnung der Stabw von e(i) und r(i)=e(i)/Stabw(x(i))-------------------------------------        	
	do j=1,ndays						
		do i=1,nyears
		r_tnn(i,j)=e_tnn(i,j)/sqrt(vtnnn(j))	!Berechnung der r_tnn(i,j) Gesamtjahr
		r_txx(i,j)=e_txx(i,j)/sqrt(vtxxx(j))    !Berechnung der r_txx(i,j) Gesamtjahr		 
		r_rr(i,j)=e_rr(i,j)/sqrt(vrrr(j))	!Berechnung der r_rr(i,j) Gesamtjahr		
		end do
	end do
	
	r_tnn_1=r_tnn(1:nyears,a_1:b_1)			!Aufteilung der Residuen aus Gesamtjahr...
	r_txx_1=r_txx(1:nyears,a_1:b_1)			!...in die 5 'Jahreszeiten'
	r_rr_1=r_rr(1:nyears,a_1:b_1)
	
	r_tnn_2=r_tnn(1:nyears,a_2:b_2)
	r_txx_2=r_txx(1:nyears,a_2:b_2)
	r_rr_2=r_rr(1:nyears,a_2:b_2)
	
	r_tnn_3=r_tnn(1:nyears,a_3:b_3)
	r_txx_3=r_txx(1:nyears,a_3:b_3)
	r_rr_3=r_rr(1:nyears,a_3:b_3)
	
	r_tnn_4=r_tnn(1:nyears,a_4:b_4)
	r_txx_4=r_txx(1:nyears,a_4:b_4)
	r_rr_4=r_rr(1:nyears,a_4:b_4)
	
	r_tnn_5=r_tnn(1:nyears,a_5:b_5)
	r_txx_5=r_txx(1:nyears,a_5:b_5)
	r_rr_5=r_rr(1:nyears,a_5:b_5)	

!	write(8,'(113(f5.1,1x))') ((r_rr(i,j),i=1,113),j=1,365)       	            	       	

!Berechnung des Markovkoeffizienten a  -----------------------------------------------------------------       	
       	sum_r_tnn1_1=null
       	sum_r_tnn2_1=null
       	sum_r_txx1_1=null
       	sum_r_txx2_1=null       	
       	sum_r_rr1_1=null
       	sum_r_rr2_1=null
       	sum_r_tnn1_2=null
       	sum_r_tnn2_2=null
       	sum_r_txx1_2=null
       	sum_r_txx2_2=null       	
       	sum_r_rr1_2=null
       	sum_r_rr2_2=null
       	sum_r_tnn1_3=null
       	sum_r_tnn2_3=null
       	sum_r_txx1_3=null
       	sum_r_txx2_3=null       	
       	sum_r_rr1_3=null
       	sum_r_rr2_3=null
       	sum_r_tnn1_4=null
       	sum_r_tnn2_4=null
       	sum_r_txx1_4=null
       	sum_r_txx2_4=null       	
       	sum_r_rr1_4=null
       	sum_r_rr2_4=null
       	sum_r_tnn1_5=null
       	sum_r_tnn2_5=null
       	sum_r_txx1_5=null
       	sum_r_txx2_5=null       	
       	sum_r_rr1_5=null
       	sum_r_rr2_5=null            	
	
!	write(8,'(1(f4.1,1x))') r_tnn_neu	
	r_tnn_11=transpose(r_tnn_1)	!Transponieren der Residuenmatrix
	r_txx_11=transpose(r_txx_1)	!hier nichts aendern!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
	r_rr_11=transpose(r_rr_1)	!da r_xxx_neu_y in simulate verwendet wird !!!!!!!!!!!!!!!!!!!!!
	r_tnn_22=transpose(r_tnn_2)
	r_txx_22=transpose(r_txx_2)
	r_rr_22=transpose(r_rr_2)
	r_tnn_33=transpose(r_tnn_3)
	r_txx_33=transpose(r_txx_3)
	r_rr_33=transpose(r_rr_3)
	r_tnn_44=transpose(r_tnn_4)
	r_txx_44=transpose(r_txx_4)
	r_rr_44=transpose(r_rr_4)
	r_tnn_55=transpose(r_tnn_5)
	r_txx_55=transpose(r_txx_5)
	r_rr_55=transpose(r_rr_5)

	r_tnn_neu_1=pack(r_tnn_11, r_tnn_11.ne.-999.45656_sp)	!transponierte Residuenmatrix...
	r_txx_neu_1=pack(r_txx_11, r_txx_11.ne.-999.45656_sp)   !...-->Residuenvektor
	r_rr_neu_1=pack(r_rr_11, r_rr_11.ne.-999.45656_sp)
	r_tnn_neu_2=pack(r_tnn_22, r_tnn_22.ne.-999.45656_sp)	
	r_txx_neu_2=pack(r_txx_22, r_txx_22.ne.-999.45656_sp)
	r_rr_neu_2=pack(r_rr_22, r_rr_22.ne.-999.45656_sp)
	r_tnn_neu_3=pack(r_tnn_33, r_tnn_33.ne.-999.45656_sp)
	r_txx_neu_3=pack(r_txx_33, r_txx_33.ne.-999.45656_sp)
	r_rr_neu_3=pack(r_rr_33, r_rr_33.ne.-999.45656_sp)
	r_tnn_neu_4=pack(r_tnn_44, r_tnn_44.ne.-999.45656_sp)
	r_txx_neu_4=pack(r_txx_44, r_txx_44.ne.-999.45656_sp)
	r_rr_neu_4=pack(r_rr_44, r_rr_44.ne.-999.45656_sp)
	r_tnn_neu_5=pack(r_tnn_55, r_tnn_55.ne.-999.45656_sp)
	r_txx_neu_5=pack(r_txx_55, r_txx_55.ne.-999.45656_sp)
	r_rr_neu_5=pack(r_rr_55, r_rr_55.ne.-999.45656_sp)
	
	do k=1,1
	r_tnn_neu_1(k)=r_tnn_neu_1(k)
	r_txx_neu_1(k)=r_txx_neu_1(k)
	r_rr_neu_1(k)=r_rr_neu_1(k)
	end do	
	do k=2,nyears*seventhree		
		sum_r_tnn1_1=sum_r_tnn1_1+(r_tnn_neu_1(k)*r_tnn_neu_1(k-1)) !Dividend fuer a_markov
		sum_r_tnn2_1=sum_r_tnn2_1+(r_tnn_neu_1(k)*r_tnn_neu_1(k))   !Divisor fuer a_markov
		sum_r_txx1_1=sum_r_txx1_1+(r_txx_neu_1(k)*r_txx_neu_1(k-1))
		sum_r_txx2_1=sum_r_txx2_1+(r_txx_neu_1(k)*r_txx_neu_1(k))
		sum_r_rr1_1=sum_r_rr1_1+(r_rr_neu_1(k)*r_rr_neu_1(k-1))
		sum_r_rr2_1=sum_r_rr2_1+(r_rr_neu_1(k)*r_rr_neu_1(k))
	end do	 
        a_markov_tnn_1=sum_r_tnn1_1/sum_r_tnn2_1			    !a_markov=Dividend/Divisor
        a_markov_txx_1=sum_r_txx1_1/sum_r_txx2_1
        a_markov_rr_1=sum_r_rr1_1/sum_r_rr2_1
!--------------------------------------------------------------------------------------------------        

	do k=1,1
	r_tnn_neu_2(k)=r_tnn_neu_2(k)
	r_txx_neu_2(k)=r_txx_neu_2(k)
	r_rr_neu_2(k)=r_rr_neu_2(k)
	end do	        
        do k=2,nyears*seventhree		
		sum_r_tnn1_2=sum_r_tnn1_2+(r_tnn_neu_2(k)*r_tnn_neu_2(k-1)) !
		sum_r_tnn2_2=sum_r_tnn2_2+(r_tnn_neu_2(k)*r_tnn_neu_2(k))
		sum_r_txx1_2=sum_r_txx1_2+(r_txx_neu_2(k)*r_txx_neu_2(k-1))
		sum_r_txx2_2=sum_r_txx2_2+(r_txx_neu_2(k)*r_txx_neu_2(k))
		sum_r_rr1_2=sum_r_rr1_2+(r_rr_neu_2(k)*r_rr_neu_2(k-1))
		sum_r_rr2_2=sum_r_rr2_2+(r_rr_neu_2(k)*r_rr_neu_2(k))
	end do	 
        a_markov_tnn_2=sum_r_tnn1_2/sum_r_tnn2_2
        a_markov_txx_2=sum_r_txx1_2/sum_r_txx2_2
        a_markov_rr_2=sum_r_rr1_2/sum_r_rr2_2
!--------------------------------------------------------------------------------------------------               

	do k=1,1
	r_tnn_neu_3(k)=r_tnn_neu_3(k)
	r_txx_neu_3(k)=r_txx_neu_3(k)
	r_rr_neu_3(k)=r_rr_neu_3(k)
	end do	         
        do k=2,nyears*seventhree        	
		sum_r_tnn1_3=sum_r_tnn1_3+(r_tnn_neu_3(k)*r_tnn_neu_3(k-1))
		sum_r_tnn2_3=sum_r_tnn2_3+(r_tnn_neu_3(k)*r_tnn_neu_3(k))
		sum_r_txx1_3=sum_r_txx1_3+(r_txx_neu_3(k)*r_txx_neu_3(k-1))
		sum_r_txx2_3=sum_r_txx2_3+(r_txx_neu_3(k)*r_txx_neu_3(k))
		sum_r_rr1_3=sum_r_rr1_3+(r_rr_neu_3(k)*r_rr_neu_3(k-1))
		sum_r_rr2_3=sum_r_rr2_3+(r_rr_neu_3(k)*r_rr_neu_3(k))
	end do	 
        a_markov_tnn_3=sum_r_tnn1_3/sum_r_tnn2_3
        a_markov_txx_3=sum_r_txx1_3/sum_r_txx2_3
        a_markov_rr_3=sum_r_rr1_3/sum_r_rr2_3
!--------------------------------------------------------------------------------------------------               

	do k=1,1
	r_tnn_neu_4(k)=r_tnn_neu_4(k)
	r_txx_neu_4(k)=r_txx_neu_4(k)
	r_rr_neu_4(k)=r_rr_neu_4(k)
	end do	         
        do k=2,nyears*seventhree		
		sum_r_tnn1_4=sum_r_tnn1_4+(r_tnn_neu_4(k)*r_tnn_neu_4(k-1))
		sum_r_tnn2_4=sum_r_tnn2_4+(r_tnn_neu_4(k)*r_tnn_neu_4(k))
		sum_r_txx1_4=sum_r_txx1_4+(r_txx_neu_4(k)*r_txx_neu_4(k-1))
		sum_r_txx2_4=sum_r_txx2_4+(r_txx_neu_4(k)*r_txx_neu_4(k))
		sum_r_rr1_4=sum_r_rr1_4+(r_rr_neu_4(k)*r_rr_neu_4(k-1))
		sum_r_rr2_4=sum_r_rr2_4+(r_rr_neu_4(k)*r_rr_neu_4(k))
	end do	 
        a_markov_tnn_4=sum_r_tnn1_4/sum_r_tnn2_4
        a_markov_txx_4=sum_r_txx1_4/sum_r_txx2_4
        a_markov_rr_4=sum_r_rr1_4/sum_r_rr2_4 
!--------------------------------------------------------------------------------------------------               

	do k=1,1
	r_tnn_neu_5(k)=r_tnn_neu_5(k)
	r_txx_neu_5(k)=r_txx_neu_5(k)
	r_rr_neu_5(k)=r_rr_neu_5(k)
	end do	        
        do k=2,nyears*seventhree		
		sum_r_tnn1_5=sum_r_tnn1_5+(r_tnn_neu_5(k)*r_tnn_neu_5(k-1))
		sum_r_tnn2_5=sum_r_tnn2_5+(r_tnn_neu_5(k)*r_tnn_neu_5(k))
		sum_r_txx1_5=sum_r_txx1_5+(r_txx_neu_5(k)*r_txx_neu_5(k-1))
		sum_r_txx2_5=sum_r_txx2_5+(r_txx_neu_5(k)*r_txx_neu_5(k))
		sum_r_rr1_5=sum_r_rr1_5+(r_rr_neu_5(k)*r_rr_neu_5(k-1))
		sum_r_rr2_5=sum_r_rr2_5+(r_rr_neu_5(k)*r_rr_neu_5(k))
	end do	 
        a_markov_tnn_5=sum_r_tnn1_5/sum_r_tnn2_5
        a_markov_txx_5=sum_r_txx1_5/sum_r_txx2_5
        a_markov_rr_5=sum_r_rr1_5/sum_r_rr2_5
          
	
end subroutine markov

!
!===================================================================================================
!               subroutine zum Plotten der daten
subroutine plotgnu
     use nrtype
     use variablen
     implicit none
     integer :: max_sum_tnnmin
     integer :: max_sum_tnnmax
     integer :: max_sum_txxmin
     integer :: max_sum_txxmax
     integer :: max_sum_rrmax
     
     max_sum_tnnmin=nint(0.5_sp*maxval(sumtnnmin))	!Bestimmung der y-Achsen Skalierung.
     max_sum_tnnmax=nint(0.5_sp*maxval(sumtnnmax))
     if(abfrage_weitere1.eq.'j') then
     max_sum_txxmin=nint(0.5_sp*maxval(sumtxxmin))
     max_sum_txxmax=nint(0.5_sp*maxval(sumtxxmax))
     end if
     if(abfrage_weitere2.eq.'j') then
     max_sum_rrmax=nint(0.7_sp*maxval(sumrrmax))
     end if
               
     open(458,file='gnuskript.plt',err=10)		!Schreiben des Gnuplot Skriptfiles.
     write(458,*) 'set xrange [',anfangsjahr+1,':',anfangsjahr+nyears,']'
     write(458,*) 'set xlabel "Jahr"'
     write(458,*) 'set xtics',nint(nyears/10.0_sp)
     write(458,*) 'set tics out' 
     write(458,*) 'set ylabel "Summe der ExUebertreffung in K"'
     write(458,*) 'set boxwidth 1.0'
     write(458,*) 'set style fill solid 1 border -3'
     write(458,*) 'set title "Daten aus TNNmin.txt, Zeitraum=',zeitraum,'"'
     write(458,*) 'set yrange [0:',max_sum_tnnmin,']'
     write(458,*) 'plot  "t_Ausgabe_TNNmin.txt" using 1:8 title "orig." with boxes 9,\'
     write(458,*) '"t_Ausgabe_TNNmin.txt" using 1:7 title "99.9%" with lines 1,\'
     write(458,*) '"t_Ausgabe_TNNmin.txt" using 1:6 title "99%" with lines 2,\'
     write(458,*) '"t_Ausgabe_TNNmin.txt" using 1:5 title "95%" with lines 3'
     write(458,*) 'pause -1'
     write(458,*) 'set title "Daten aus TNNmax.txt, Zeitraum=',zeitraum,'"'
     write(458,*) 'set yrange [0:',max_sum_tnnmax,']'
     write(458,*) 'plot  "t_Ausgabe_TNNmax.txt" using 1:8 title "orig." with boxes 9,\'
     write(458,*) '"t_Ausgabe_TNNmax.txt" using 1:7 title "99.9%" with lines 1,\'
     write(458,*) '"t_Ausgabe_TNNmax.txt" using 1:6 title "99%" with lines 2,\'
     write(458,*) '"t_Ausgabe_TNNmax.txt" using 1:5 title "95%" with lines 3'
     write(458,*) 'pause -1'
     if(abfrage_weitere1.eq.'j') then
     write(458,*) 'set title "Daten aus TXXmin.txt, Zeitraum=',zeitraum,'"'
     write(458,*) 'set yrange [0:',max_sum_txxmin,']'
     write(458,*) 'plot  "t_Ausgabe_TXXmin.txt" using 1:8 title "orig." with boxes 9,\'
     write(458,*) '"t_Ausgabe_TXXmin.txt" using 1:7 title "99.9%" with lines 1,\'
     write(458,*) '"t_Ausgabe_TXXmin.txt" using 1:6 title "99%" with lines 2,\'
     write(458,*) '"t_Ausgabe_TXXmin.txt" using 1:5 title "95%" with lines 3'
     write(458,*) 'pause -1'
     write(458,*) 'set title "Daten aus TXXmax.txt, Zeitraum=',zeitraum,'"'
     write(458,*) 'set yrange [0:',max_sum_txxmax,']'
     write(458,*) 'plot  "t_Ausgabe_TXXmax.txt" using 1:8 title "orig." with boxes 9,\'
     write(458,*) '"t_Ausgabe_TXXmax.txt" using 1:7 title "99.9%" with lines 1,\'
     write(458,*) '"t_Ausgabe_TXXmax.txt" using 1:6 title "99%" with lines 2,\'
     write(458,*) '"t_Ausgabe_TXXmax.txt" using 1:5 title "95%" with lines 3'
     write(458,*) 'pause -1'
     end if
     if(abfrage_weitere2.eq.'j') then
     write(458,*) 'set title "Daten aus RRmax.txt, Zeitraum=',zeitraum,'"'
     write(458,*) 'set yrange [0:',max_sum_rrmax,']'
     write(458,*) 'plot  "t_Ausgabe_RRmax.txt" using 1:8 title "orig." with boxes 9,\'
     write(458,*) '"t_Ausgabe_RRmax.txt" using 1:7 title "99.9%" with lines 1,\'
     write(458,*) '"t_Ausgabe_RRmax.txt" using 1:6 title "99%" with lines 2,\'
     write(458,*) '"t_Ausgabe_RRmax.txt" using 1:5 title "95%" with lines 3'
     write(458,*) 'pause -1'
     end if
     
     write(458,*) 'reset'
     write(458,*) 'set terminal postscript color'
        
     write(458,*) 'set xrange [',anfangsjahr+1,':',anfangsjahr+nyears,']'
     write(458,*) 'set xlabel "Jahr"'
     write(458,*) 'set xtics',nint(nyears/10.0_sp)
     write(458,*) 'set tics out' 
     write(458,*) 'set ylabel "Summe der ExUebertreffung in K"'
     write(458,*) 'set boxwidth 1.0'
     write(458,*) 'set style fill solid 1 border -3'
     write(458,*) 'set title "Daten aus TNNmin.txt, Zeitraum=',zeitraum,'"'
     write(458,*) 'set yrange [0:',max_sum_tnnmin,']'
     write(458,*) 'set output "t_TNNmin.ps"'
     write(458,*) 'plot  "t_Ausgabe_TNNmin.txt" using 1:8 title "orig." with boxes 9,\'
     write(458,*) '"t_Ausgabe_TNNmin.txt" using 1:7 title "99.9%" with lines 1,\'
     write(458,*) '"t_Ausgabe_TNNmin.txt" using 1:6 title "99%" with lines 2,\'
     write(458,*) '"t_Ausgabe_TNNmin.txt" using 1:5 title "95%" with lines 3'
     write(458,*) 'set title "Daten aus TNNmax.txt, Zeitraum=',zeitraum,'"'
     write(458,*) 'set yrange [0:',max_sum_tnnmax,']'
     write(458,*) 'set output "t_TNNmax.ps"'
     write(458,*) 'plot  "t_Ausgabe_TNNmax.txt" using 1:8 title "orig." with boxes 9,\'
     write(458,*) '"t_Ausgabe_TNNmax.txt" using 1:7 title "99.9%" with lines 1,\'
     write(458,*) '"t_Ausgabe_TNNmax.txt" using 1:6 title "99%" with lines 2,\'
     write(458,*) '"t_Ausgabe_TNNmax.txt" using 1:5 title "95%" with lines 3'
     if(abfrage_weitere1.eq.'j') then
     write(458,*) 'set title "Daten aus TXXmin.txt, Zeitraum=',zeitraum,'"'
     write(458,*) 'set yrange [0:',max_sum_txxmin,']'
     write(458,*) 'set output "t_TXXmin.ps"'
     write(458,*) 'plot  "t_Ausgabe_TXXmin.txt" using 1:8 title "orig." with boxes 9,\'
     write(458,*) '"t_Ausgabe_TXXmin.txt" using 1:7 title "99.9%" with lines 1,\'
     write(458,*) '"t_Ausgabe_TXXmin.txt" using 1:6 title "99%" with lines 2,\'
     write(458,*) '"t_Ausgabe_TXXmin.txt" using 1:5 title "95%" with lines 3'
     write(458,*) 'set title "Daten aus TXXmax.txt, Zeitraum=',zeitraum,'"'
     write(458,*) 'set yrange [0:',max_sum_txxmax,']'
     write(458,*) 'set output "t_TXXmax.ps"'
     write(458,*) 'plot  "t_Ausgabe_TXXmax.txt" using 1:8 title "orig." with boxes 9,\'
     write(458,*) '"t_Ausgabe_TXXmax.txt" using 1:7 title "99.9%" with lines 1,\'
     write(458,*) '"t_Ausgabe_TXXmax.txt" using 1:6 title "99%" with lines 2,\'
     write(458,*) '"t_Ausgabe_TXXmax.txt" using 1:5 title "95%" with lines 3'
     end if
     if(abfrage_weitere2.eq.'j') then
     write(458,*) 'set title "Daten aus RRmax.txt, Zeitraum=',zeitraum,'"'
     write(458,*) 'set yrange [0:',max_sum_rrmax,']'
     write(458,*) 'set output "t_RRmax.ps"'
     write(458,*) 'plot  "t_Ausgabe_RRmax.txt" using 1:8 title "orig." with boxes 9,\'
     write(458,*) '"t_Ausgabe_RRmax.txt" using 1:7 title "99.9%" with lines 1,\'
     write(458,*) '"t_Ausgabe_RRmax.txt" using 1:6 title "99%" with lines 2,\'
     write(458,*) '"t_Ausgabe_RRmax.txt" using 1:5 title "95%" with lines 3'
     end if
     
     close(458)
  
10   call system ('gnuplot.exe gnuskript.plt')		!Aufrufen von 'gnuplot.exe' inkl. dem Skriptfile 'gnuskript.plt'		

end subroutine plotgnu
!
!===================================================================================================
!               subroutine zur Erzeugung einer Zufallszahl

subroutine ranseed
        use nrtype
        use nr, only: ran
        implicit none
!       Seeds random number generator.
        integer :: seed=0
        real(sp) :: dummy=-999.0_sp
!        print *,'seed random number generator (negative integer): '
!        read (5,*) seed
        seed=-3118152867
        dummy=ran(seed)
 end subroutine ranseed
!
!===================================================================================================
!               subroutine zum Datenauslesen aus klimadaten.txt sowie schreiben der tnn, txx, rr in
!               3 seperate Dateien zur Weiterverwendung (matrix_xxx.txt)

 subroutine read_klimadatei
        use nrtype
        use parameters
        use variablen
        implicit none
	integer  :: i           !Das sind die Laufvariablen fuer die Jahre
      	integer  :: j           !Das sind die Laufvariablen fuer die Tage
        real(sp) :: tn		!Diese Variablen werden aus den...
        real(sp) :: tx		!...Klimadaten-Dateien eingelesen.
        real(sp) :: r
        integer  :: jahr1
        character(len=2) :: monat
        character(len=2) :: tag
        
        open(10,file=abfrage_datei1)          
        read(10,*) 
        
        if(abfrage_weitere1.eq.'j') then
        open(20,file=abfrage_datei2)
        read(20,*)
        end if
        
        if(abfrage_weitere2.eq.'j') then
        open(30,file=abfrage_datei3)
        read(30,*)
        end if        
       
        do i=1,nyears
                do j=1,ndays
                
		read(10,*) tn
		
		if(abfrage_weitere1.eq.'j') then
        	read(20,*) tx        	
       		end if
        
        	if(abfrage_weitere2.eq.'j') then
        	read(30,*) r
        	end if

                matrixtnn(i,j)=tn		!schreiben der Klimadaten in Matrixform
                
                if(abfrage_weitere1.eq.'j') then
        	matrixtxx(i,j)=tx
        	else
        	matrixtxx(i,j)=0.0
        	end if
        
        	if(abfrage_weitere2.eq.'j') then
        	matrixrr(i,j)=r
        	else
        	matrixrr(i,j)=0.0
        	end if
        	
                matrixtxx(i,j)=tx
                matrixrr(i,j)=r
                
                if(r.eq.-99.9) then		!um evtl. fehlende Werte zu vermeiden
                matrixrr(i,j)=0.0	
                end if

                end do
        end do

        close(10)
        
        if(abfrage_weitere1.eq.'j') then
        close(20)
        end if
        
        if(abfrage_weitere2.eq.'j') then
        close(30)
        end if

 end subroutine read_klimadatei
!
!==================================================================================================
!      subroutine zur Simulation von taegl. Minimum- und Maximumtemperaturen sowie Niederschlagswerten
!
 subroutine simulate	

        use nrtype
        use parameters
        use variablen
        use sim
        use stats
        use boot
        implicit none

        real(sp), dimension(1:nyears,1:ndays) :: matrixtnn_sim !simulierte Klimavariable1
        real(sp), dimension(1:nyears,1:ndays) :: matrixtxx_sim !simulierte Klimavariable2
        real(sp), dimension(1:nyears,1:ndays) :: matrixrr_sim  !simulierte Klimavariable3
 
	integer :: i                                      !Das sind die Laufvariablen...  Jahre
      	integer :: j                                      !...fuer die do-Schleifen.      Tage
      	integer :: k                                      !Anzahl der Simulationen       	
      	
!	open(8,file='ausgabe.txt')
	 write(*,'(a13)') 'Simulation...'
         do k=1,n_sim
            if (mod(k,20) .eq. 0) print *, ' k = ',k, ' von ',n_sim 	!Fortschrittszaehler            
                
            call bootm(r_tnn_neu_1,seventhree*nyears,l_mbb_tnn_1,r_tn_resample_1) !Aufruf der Bootstrap-Subroutine
            call bootm(r_txx_neu_1,seventhree*nyears,l_mbb_txx_1,r_tx_resample_1)
            call bootm(r_rr_neu_1,seventhree*nyears,l_mbb_rr_1,r_rr_resample_1)
            call bootm(r_tnn_neu_2,seventhree*nyears,l_mbb_tnn_2,r_tn_resample_2) 
            call bootm(r_txx_neu_2,seventhree*nyears,l_mbb_txx_2,r_tx_resample_2)
            call bootm(r_rr_neu_2,seventhree*nyears,l_mbb_rr_2,r_rr_resample_2)
            call bootm(r_tnn_neu_3,seventhree*nyears,l_mbb_tnn_3,r_tn_resample_3) 
            call bootm(r_txx_neu_3,seventhree*nyears,l_mbb_txx_3,r_tx_resample_3)
            call bootm(r_rr_neu_3,seventhree*nyears,l_mbb_rr_3,r_rr_resample_3)
            call bootm(r_tnn_neu_4,seventhree*nyears,l_mbb_tnn_4,r_tn_resample_4) 
            call bootm(r_txx_neu_4,seventhree*nyears,l_mbb_txx_4,r_tx_resample_4)
            call bootm(r_rr_neu_4,seventhree*nyears,l_mbb_rr_4,r_rr_resample_4)
            call bootm(r_tnn_neu_5,seventhree*nyears,l_mbb_tnn_5,r_tn_resample_5) 
            call bootm(r_txx_neu_5,seventhree*nyears,l_mbb_txx_5,r_tx_resample_5)
            call bootm(r_rr_neu_5,seventhree*nyears,l_mbb_rr_5,r_rr_resample_5)
           
            	r_tn_resample_1_neu(1:nyears,a_1:b_1)=r_tn_resample_1	!Festlegung eines nyears mal seventhree Feldes fuer r_tn_resample_1
		r_tx_resample_1_neu(1:nyears,a_1:b_1)=r_tx_resample_1
		r_rr_resample_1_neu(1:nyears,a_1:b_1)=r_rr_resample_1
	
		r_tn_resample_2_neu(1:nyears,a_2:b_2)=r_tn_resample_2
		r_tx_resample_2_neu(1:nyears,a_2:b_2)=r_tx_resample_2
		r_rr_resample_2_neu(1:nyears,a_2:b_2)=r_rr_resample_2
	
		r_tn_resample_3_neu(1:nyears,a_3:b_3)=r_tn_resample_3
		r_tx_resample_3_neu(1:nyears,a_3:b_3)=r_tx_resample_3
		r_rr_resample_3_neu(1:nyears,a_3:b_3)=r_rr_resample_3
	
		r_tn_resample_4_neu(1:nyears,a_4:b_4)=r_tn_resample_4
		r_tx_resample_4_neu(1:nyears,a_4:b_4)=r_tx_resample_4
		r_rr_resample_4_neu(1:nyears,a_4:b_4)=r_rr_resample_4
	
		r_tn_resample_5_neu(1:nyears,a_5:b_5)=r_tn_resample_5
		r_tx_resample_5_neu(1:nyears,a_5:b_5)=r_tx_resample_5
		r_rr_resample_5_neu(1:nyears,a_5:b_5)=r_rr_resample_5 
               
	 	              
            do i=1,nyears
               	  do j=a_1,b_1               
               	  matrixtnn_sim(i,j)=a_fit_tnn(j)+b_fit_tnn(j)*i+  &	!Hier entstehen die Simulierten Zeitreihen.
                  sqrt(vtnnn(j))*r_tn_resample_1_neu(i,j)                
                  matrixtxx_sim(i,j)=a_fit_txx(j)+b_fit_txx(j)*i+  &
                  sqrt(vtxxx(j))*r_tx_resample_1_neu(i,j)                  
                  matrixrr_sim(i,j)=a_fit_rr(j)+b_fit_rr(j)*i+  &
                  sqrt(vrrr(j))*r_rr_resample_1_neu(i,j)
                  if(matrixrr_sim(i,j).lt.0.0) then 			!herausfiltern von RR<0.0mm		
                  matrixrr_sim(i,j)=0.0											
                  else
                  matrixrr_sim(i,j)=matrixrr_sim(i,j)
                  end if
                  end do
            end do
                                   
            do i=1,nyears
               	  do j=a_2,b_2                   
               	  matrixtnn_sim(i,j)=a_fit_tnn(j)+b_fit_tnn(j)*i+  &	
                  sqrt(vtnnn(j))*r_tn_resample_2_neu(i,j)                
                  matrixtxx_sim(i,j)=a_fit_txx(j)+b_fit_txx(j)*i+  &
                  sqrt(vtxxx(j))*r_tx_resample_2_neu(i,j)                  
                  matrixrr_sim(i,j)=a_fit_rr(j)+b_fit_rr(j)*i+  &
                  sqrt(vrrr(j))*r_rr_resample_2_neu(i,j)
                  if(matrixrr_sim(i,j).lt.0.0) then 				
                  matrixrr_sim(i,j)=0.0						
                  else
                  matrixrr_sim(i,j)=matrixrr_sim(i,j)
                  end if
                  end do
            end do
                  
            do i=1,nyears
               	  do j=a_3,b_3                     
               	  matrixtnn_sim(i,j)=a_fit_tnn(j)+b_fit_tnn(j)*i+  &	
                  sqrt(vtnnn(j))*r_tn_resample_3_neu(i,j)                
                  matrixtxx_sim(i,j)=a_fit_txx(j)+b_fit_txx(j)*i+  &
                  sqrt(vtxxx(j))*r_tx_resample_3_neu(i,j)                  
                  matrixrr_sim(i,j)=a_fit_rr(j)+b_fit_rr(j)*i+  &
                  sqrt(vrrr(j))*r_rr_resample_3_neu(i,j)
                  if(matrixrr_sim(i,j).lt.0.0) then 				
                  matrixrr_sim(i,j)=0.0						
                  else
                  matrixrr_sim(i,j)=matrixrr_sim(i,j)
                  end if
                  end do
            end do
                  
            do i=1,nyears
               	  do j=a_4,b_4              
               	  matrixtnn_sim(i,j)=a_fit_tnn(j)+b_fit_tnn(j)*i+  &	
                  sqrt(vtnnn(j))*r_tn_resample_4_neu(i,j)                
                  matrixtxx_sim(i,j)=a_fit_txx(j)+b_fit_txx(j)*i+  &
                  sqrt(vtxxx(j))*r_tx_resample_4_neu(i,j)                  
                  matrixrr_sim(i,j)=a_fit_rr(j)+b_fit_rr(j)*i+  &
                  sqrt(vrrr(j))*r_rr_resample_4_neu(i,j)
                  if(matrixrr_sim(i,j).lt.0.0) then 				
                  matrixrr_sim(i,j)=0.0						
                  else
                  matrixrr_sim(i,j)=matrixrr_sim(i,j)
                  end if
                  end do
            end do
                  
            do i=1,nyears
               	  do j=a_5,b_5                       
               	  matrixtnn_sim(i,j)=a_fit_tnn(j)+b_fit_tnn(j)*i+  &	
                  sqrt(vtnnn(j))*r_tn_resample_5_neu(i,j)                
                  matrixtxx_sim(i,j)=a_fit_txx(j)+b_fit_txx(j)*i+  &
                  sqrt(vtxxx(j))*r_tx_resample_5_neu(i,j)                  
                  matrixrr_sim(i,j)=a_fit_rr(j)+b_fit_rr(j)*i+  &
                  sqrt(vrrr(j))*r_rr_resample_5_neu(i,j)
                  if(matrixrr_sim(i,j).lt.0.0) then 				
                  matrixrr_sim(i,j)=0.0						
                  else
                  matrixrr_sim(i,j)=matrixrr_sim(i,j)
                  end if
                  end do
            end do                  
                                           
            call solve(matrixtnn_sim,matrixtxx_sim,matrixrr_sim,  & !Aufruf der solve-Subroutine zur Berechnung...
                       sum1_sim(1:nyears,k),sum2_sim(1:nyears,k), & !... der simulierten Summen,Anzahlen,Produkte
                       sum3_sim(1:nyears,k),sum4_sim(1:nyears,k), &
                       sum5_sim(1:nyears,k),                      &
                       anz1_sim(1:nyears,k),anz2_sim(1:nyears,k), &
                       anz3_sim(1:nyears,k),anz4_sim(1:nyears,k), &
                       anz5_sim(1:nyears,k),			  &	
                       pro1_sim(1:nyears,k),pro2_sim(1:nyears,k), &
                       pro3_sim(1:nyears,k),pro4_sim(1:nyears,k), &
                       pro5_sim(1:nyears,k),			  &
  		       nyears,ndays)          
        
            if(k.eq.1) then                                
!            write(8,999)((matrixtnn_sim(i,j),i=1,113),j=1,365)    !Kontrollausgabe einer simulierten Zeitreihe            
	    end if                  
                       	
         end do					!Ende der Simulationsschleife
               	
!         close(8)
999      format(113(1X,f7.1))

 end subroutine simulate
 !
 !==================================================================================================
 !      subroutine zur Berechnung der Summe/Anzahl der Extremwertuebertreffungen pro Jahr
 !      sowie der Ausgabe in die Datei SummeVerbesserung.txt/AnzahlVerbesserung.txt

 subroutine solve(x,y,z,summe11,summe12,summe13,summe14,summe15,        &
                anzahl11,anzahl12,anzahl13,anzahl14,anzahl15,produkt11, &
                produkt12,produkt13,produkt14,produkt15,ny,nd)
        use nrtype
        use parameters
        use variablen
        implicit none

        integer, intent(in) :: ny
        integer, intent(in) :: nd
        real(sp), dimension(1:ny,1:nd), intent(in) :: x         !x entspr. matrixtnn (Tagesminimumtemperatur)
        real(sp), dimension(1:ny,1:nd), intent(in) :: y         !y entspr. matrixtxx (Tagesmaximumtemperatur)
        real(sp), dimension(1:ny,1:nd), intent(in) :: z         !z entspr. matrixrr  (Tagesniederschlag)

        real(sp), dimension(1:ny), intent(out) :: summe11       !Summe der Extremwertuebertreffungen fr TNNmin
        real(sp), dimension(1:ny), intent(out) :: summe12       !Summe der Extremwertuebertreffungen fr TNNmax
        real(sp), dimension(1:ny), intent(out) :: summe13       !Summe der Extremwertuebertreffungen fr TXXmin
        real(sp), dimension(1:ny), intent(out) :: summe14       !Summe der Extremwertuebertreffungen fr TXXmax
        real(sp), dimension(1:ny), intent(out) :: summe15       !Summe der Extremwertuebertreffungen fr RRmax
        real(sp), dimension(1:ny), intent(out) :: anzahl11      !Anzahl der Extremwertuebertreffungen fr TNNmin
        real(sp), dimension(1:ny), intent(out) :: anzahl12      !Anzahl der Extremwertuebertreffungen fr TNNmax
        real(sp), dimension(1:ny), intent(out) :: anzahl13      !Anzahl der Extremwertuebertreffungen fr TXXmin
        real(sp), dimension(1:ny), intent(out) :: anzahl14      !Anzahl der Extremwertuebertreffungen fr TXXmax
        real(sp), dimension(1:ny), intent(out) :: anzahl15      !Anzahl der Extremwertuebertreffungen fr RRmax
        real(sp), dimension(1:ny), intent(out) :: produkt11       !Produkt Summe*Anzahl fr TNNmin
        real(sp), dimension(1:ny), intent(out) :: produkt12       !Produkt Summe*Anzahl fr TNNmax
        real(sp), dimension(1:ny), intent(out) :: produkt13       !Produkt Summe*Anzahl fr TXXmin
        real(sp), dimension(1:ny), intent(out) :: produkt14       !Produkt Summe*Anzahl fr TXXmax
        real(sp), dimension(1:ny), intent(out) :: produkt15       !Produkt Summe*Anzahl fr RRmax
        real(sp), dimension(1:ny)              :: summe6
        real(sp), dimension(1:ny)              :: summe7
        real(sp), dimension(1:ny)              :: summe8
        real(sp), dimension(1:ny)              :: summe9
        real(sp), dimension(1:ny)              :: summe10
        real(sp), dimension(1:ny)              :: summe1
        real(sp), dimension(1:ny)              :: summe2
        real(sp), dimension(1:ny)              :: summe3
        real(sp), dimension(1:ny)              :: summe4
        real(sp), dimension(1:ny)              :: summe5
        real(sp), dimension(1:ny)              :: anzahl6
        real(sp), dimension(1:ny)              :: anzahl7
        real(sp), dimension(1:ny)              :: anzahl8
        real(sp), dimension(1:ny)              :: anzahl9
        real(sp), dimension(1:ny)              :: anzahl10
        real(sp), dimension(1:ny)              :: anzahl1
        real(sp), dimension(1:ny)              :: anzahl2
        real(sp), dimension(1:ny)              :: anzahl3
        real(sp), dimension(1:ny)              :: anzahl4
        real(sp), dimension(1:ny)              :: anzahl5
        real(sp) :: delta1      !Differenz der Extremwertuebertreffungen fr TNNmin
        real(sp) :: delta2      !Differenz der Extremwertuebertreffungen fr TNNmax
        real(sp) :: delta3      !Differenz der Extremwertuebertreffungen fr TXXmin
        real(sp) :: delta4      !Differenz der Extremwertuebertreffungen fr TXXmax
        real(sp) :: delta5      !Differenz der Extremwertuebertreffungen fr RRmax
        real(sp) :: delta6      !...fuer Wintermonate
        real(sp) :: delta7
        real(sp) :: delta8
        real(sp) :: delta9
        real(sp) :: delta10

        real(sp) :: tnnmin              !die bis zu diesem Jahr kaelteste Tiefsttemp. am best. Kalendertag
        real(sp) :: tnnmax              !die bis zu diesem Jahr waermste Tiefsttemp. am best. Kalendertag
        real(sp) :: txxmin              !die bis zu diesem Jahr kaelteste Hoechsttemp. am best. Kalendertag
        real(sp) :: txxmax              !die bis zu diesem Jahr waermste Hoechsttemp. am best. Kalendertag
        real(sp) :: rrmax               !die bis zu diesem Jahr kaelteste Hoechsttemp. am best. Kalendertag
        
        integer :: i                                      !Das sind die Laufvariablen     Jahre
        integer :: j                                      !fuer die do-Schleifen.         Tage
      	integer :: a                                      !a und b sind die Laufvariablen der Kalendertage
        integer :: b                                      !fuer die versch. Jahreszeiten (j=a,b)
      	integer :: c                                      !c und d werden zusaetzlich benoetigt
      	integer :: d                                      !fuer die Berechnung der Wintermonate
        integer :: k                                      !Anzahl der Zufallszahlen

        real(sp), dimension(1:ny,1:nd) :: aa        !Hilfsvariablen fuer Anzahl der Verbesserungen
        real(sp), dimension(1:ny,1:nd) :: bb
        real(sp), dimension(1:ny,1:nd) :: cc
        real(sp), dimension(1:ny,1:nd) :: dd
        real(sp), dimension(1:ny,1:nd) :: nn
!
! Initialisierung
	summe1=null
	summe2=null
	summe3=null
	summe4=null
	summe5=null
	summe6=null
	summe7=null
	summe8=null
	summe9=null
	summe10=null
	summe11=null
	summe12=null
	summe13=null
	summe14=null
	summe15=null
	anzahl1=null
	anzahl2=null
	anzahl3=null
	anzahl4=null
	anzahl5=null
	anzahl6=null
	anzahl7=null
	anzahl8=null
	anzahl9=null
	anzahl10=null
	anzahl11=null
	anzahl12=null
	anzahl13=null
	anzahl14=null
	anzahl15=null
	produkt11=null
	produkt12=null
	produkt13=null
	produkt14=null
	produkt15=null
	
	aa=null
	bb=null
	cc=null
	dd=null
	nn=null	

      !-----------------------------------------------------------------
      !Diese Schleife ist fuer die Summenbildung der Extremwertverbesserungen
      !-----------------------------------------------------------------

        if (abfrage.eq.'j1') then       !Jahr
        a=a_j1
        b=b_j1
        zeitraum='Jan-Dez'
        end if

        if (abfrage.eq.'f1') then       !Fruehjahr (Mrz-Mai)
        a=a_f1
        b=b_f1
        zeitraum='Mrz-Mai'
        end if

        if (abfrage.eq.'s1') then       !Sommer1 (Jun-Aug)
        a=a_s1
        b=b_s1
        zeitraum='Jun-Aug'
        end if

        if (abfrage.eq.'s2') then       !Sommer2 (Mai-Sep)
        a=a_s2
        b=b_s2
        zeitraum='Mai-Sep'
        end if

        if (abfrage.eq.'h1') then       !Herbst (Sep-Nov)
        a=a_h1
        b=b_h1
        zeitraum='Sep-Nov'
        end if

        if (abfrage.eq.'w1') then       !Winter (Dez(Vorjahr)-Feb)
        a=a_w1
        b=b_w1
        c=c_w1
        d=d_w1
        zeitraum='Dez(Vorjahr)-Feb'
        end if

        if (abfrage.eq.'w2') then       !Winter (Nov(Vorjahr)-Mrz)
        a=a_w2
        b=b_w2
        c=c_w2
        d=d_w2
        zeitraum='Nov(Vorjahr)-Mrz'
        end if

	   do j=a,b
               		
                do i=1,ny

                        if(i.eq.1) then                    !Hier werden die Anfangswerte (fuer 1893)
                                tnnmin=x(i,j)              !festgelegt
                                tnnmax=x(i,j)
                                txxmin=y(i,j)
                                txxmax=y(i,j)
                                rrmax=z(i,j)

                                summe1(i)= null            !diese Summen werden nur im ersten Jahr 1893 auf Null
                                summe2(i)= null		   !gesetzt (fr i=1), bei i=2-113 wird immer zur
                                summe3(i)= null		   !vorhergehenden Summe dazuaddiert (diese if-Bedingung	
                                summe4(i)= null		   !wird dann bersprungen)
                                summe5(i)= null

                                anzahl1(i)=null
                                anzahl2(i)=null
                                anzahl3(i)=null
                                anzahl4(i)=null
                                anzahl5(i)=null
 
                                aa(i,j)=null
                                bb(i,j)=null
                                cc(i,j)=null
                                dd(i,j)=null
                                nn(i,j)=null
                        end if

                        if(x(i,j).lt.tnnmin) then                       !TNNmin         !Vergleich von x(i,j) mit tnnmin
                                  aa(i,j)=aa(i,j)+1
                                  anzahl1(i)=anzahl1(i)+aa(i,j)
                                  delta1=abs(x(i,j)-tnnmin)
                                  summe1(i)=summe1(i)+delta1  		!hier wird das Delta zur existierenden Summe dazuaddiert
                                  
                                  tnnmin=x(i,j)
                        end if

                        if(x(i,j).gt.tnnmax) then                       !TNNmax
                                 bb(i,j)=bb(i,j)+1
                                 anzahl2(i)=anzahl2(i)+bb(i,j)
                                 delta2=x(i,j)-tnnmax
                                 summe2(i)=summe2(i)+delta2		
                                 tnnmax=x(i,j)				
                        end if

                        if(y(i,j).lt.txxmin) then                       !TXXmin
                                 cc(i,j)=cc(i,j)+1
                                 anzahl3(i)=anzahl3(i)+cc(i,j)
                                 delta3=abs(y(i,j)-txxmin)
                                 summe3(i)=summe3(i)+delta3
                                 txxmin=y(i,j)
                        endif

                        if(y(i,j).gt.txxmax) then                       !TXXmax
                                 dd(i,j)=dd(i,j)+1
                                 anzahl4(i)=anzahl4(i)+dd(i,j)
                                 delta4=y(i,j)-txxmax
                                 summe4(i)=summe4(i)+delta4
                                 txxmax=y(i,j)
                        endif

                        if(z(i,j).gt.rrmax) then                        !RRmax
                                 nn(i,j)=nn(i,j)+1
                                 anzahl5(i)=anzahl5(i)+nn(i,j)
                                 delta5=z(i,j)-rrmax
                                 summe5(i)=summe5(i)+delta5
                                 rrmax=z(i,j)
                        endif

                end do							!Ende Jahrschleife
           enddo							!Ende Tagschleife           							
	   	   
           if((abfrage.eq.'w1').or.(abfrage.eq.'w2')) then              !fuer die Wintermonate des Vorjahres (Nov,Dez)
          
            do j=c,d

                do i=1,ny

                        if(i.eq.1) then                    !Hier werden die Anfangswerte (fuer 1893)...
                                tnnmin=x(i,j)              !...festgelegt
                                tnnmax=x(i,j)
                                txxmin=y(i,j)
                                txxmax=y(i,j)
                                rrmax=z(i,j)

                                summe6(i)= null
                                summe7(i)= null
                                summe8(i)= null
                                summe9(i)= null
                                summe10(i)= null

                                anzahl6(i)=null
                                anzahl7(i)=null
                                anzahl8(i)=null
                                anzahl9(i)=null
                                anzahl10(i)=null

                                aa(i,j)=null
                                bb(i,j)=null
                                cc(i,j)=null
                                dd(i,j)=null
                                nn(i,j)=null
                        end if

                        if(i.eq.2) then
                        	summe1(i)=null
                       		summe2(i)=null
                        	summe3(i)=null
                        	summe4(i)=null
                        	summe5(i)=null

                        	anzahl1(i)=null
                        	anzahl2(i)=null
                        	anzahl3(i)=null
                        	anzahl4(i)=null
                        	anzahl5(i)=null
                        end if


                        if(x(i,j).lt.tnnmin) then                       !TNNmin         !Vergleich von x(i,j) mit tnnmin
                                 aa(i,j)=aa(i,j)+1
                                 anzahl6(i)=anzahl6(i)+aa(i,j)
                                 delta6=abs(x(i,j)-tnnmin)
                                 summe6(i)=summe6(i)+delta6
                                 tnnmin=x(i,j)
                        end if

                        if(x(i,j).gt.tnnmax) then                       !TNNmax
                                 bb(i,j)=bb(i,j)+1
                                 anzahl7(i)=anzahl7(i)+bb(i,j)
                                 delta7=x(i,j)-tnnmax
                                 summe7(i)=summe7(i)+delta7
                                 tnnmax=x(i,j)
                        end if

                        if(y(i,j).lt.txxmin) then                       !TXXmin
                                 cc(i,j)=cc(i,j)+1
                                 anzahl8(i)=anzahl8(i)+cc(i,j)
                                 delta8=abs(y(i,j)-txxmin)
                                 summe8(i)=summe8(i)+delta8
                                 txxmin=y(i,j)
                        endif

                        if(y(i,j).gt.txxmax) then                       !TXXmax
                                 dd(i,j)=dd(i,j)+1
                                 anzahl9(i)=anzahl9(i)+dd(i,j)
                                 delta9=y(i,j)-txxmax
                                 summe9(i)=summe9(i)+delta9
                                 txxmax=y(i,j)
                        endif

                        if(z(i,j).gt.rrmax) then                        !RRmax
                                 nn(i,j)=nn(i,j)+1
                                 anzahl10(i)=anzahl10(i)+nn(i,j)
                                 delta10=z(i,j)-rrmax
                                 summe10(i)=summe10(i)+delta10
                                 rrmax=z(i,j)
                        endif

                end do

           enddo
        end if				!Ende der Winterschleife (falls w1 oder w2 gewaehlt wird)
 
          summe11(1)=null
          summe12(1)=null
          summe13(1)=null
          summe14(1)=null
          summe15(1)=null

          anzahl11(1)=null
          anzahl12(1)=null
          anzahl13(1)=null
          anzahl14(1)=null
          anzahl15(1)=null
          
          produkt11(i)=null
          produkt12(i)=null
          produkt13(i)=null
          produkt14(i)=null
          produkt15(i)=null
            
          do i=2,ny
           summe11(i)=summe1(i)+summe6(i-1)               !Hier werden die entgueltigen Summen berechnet,
           summe12(i)=summe2(i)+summe7(i-1)               !die anschliessend in das Hauptprogramm
           summe13(i)=summe3(i)+summe8(i-1)               !uebergeben werden.
           summe14(i)=summe4(i)+summe9(i-1)
           summe15(i)=summe5(i)+summe10(i-1)
	
           anzahl11(i)=anzahl1(i)+anzahl6(i-1)            !Hier werden die entgueltigen Anzahlen berechnet,
           anzahl12(i)=anzahl2(i)+anzahl7(i-1)            !die anschliessend in das Hauptprogramm
           anzahl13(i)=anzahl3(i)+anzahl8(i-1)            !uebergeben werden.
           anzahl14(i)=anzahl4(i)+anzahl9(i-1)
           anzahl15(i)=anzahl5(i)+anzahl10(i-1)
           
        produkt11(i)=anzahl1(i)*summe1(i)+anzahl6(i-1)*summe6(i-1)            !Hier werden die Produkte berechnet,
        produkt12(i)=anzahl2(i)*summe2(i)+anzahl7(i-1)*summe7(i-1)            !die anschliessend in das Hauptprogramm
        produkt13(i)=anzahl3(i)*summe3(i)+anzahl8(i-1)*summe8(i-1)            !uebergeben werden.
        produkt14(i)=anzahl4(i)*summe4(i)+anzahl9(i-1)*summe9(i-1)
        produkt15(i)=anzahl5(i)*summe5(i)+anzahl10(i-1)*summe10(i-1) 	 
         end do

end subroutine solve
!
!===================================================================================================
!               subroutine fuer den "Anfangsbildschirm" sowie die Abfrage des Berechnungsparameter

 subroutine start
        use variablen
        use sim
        use parameters
        use stats 
        use boot
        implicit none
        integer :: ii
        integer :: n_sim2
        integer :: n_sim3
        character(len=1) :: abfrage_sim
        integer :: abfrage_jahr
        integer :: ndata1, ndata2, ndata3
        integer :: iocheck
        integer :: open_error
        real(sp) :: dummy_tnn
        real(sp) :: dummy_txx
        real(sp) :: dummy_rr

        write(*,'(a49)') '*************************************************   '
        write(*,'(a49)') 'Programm fuer taegliche Extremwertuebertreffungen   '
        write(*,'(a49)') '*************************************************   '
        write(*,'(a49)') '                                                    '
        write(*,'(a49)') '                                                    '
	
        write(*,'(a19)') 'Dateinamen angeben!'		!Abfrage des Dateinamens der Klimadatendatei(en)
        write(*,'(a18)') '****************** '
        open(1,file='t_Ausgabe_TNNmin.txt')	!	Lschen von evtl. vorhandenen Ausgabedateien aus... 
        close(1,status='delete')		!	...vorherigen Programmdurchlaeufen.
        open(2,file='t_Ausgabe_TNNmax.txt')
        close(2,status='delete')
        open(3,file='t_Ausgabe_TXXmin.txt')
        close(3,status='delete')
        open(4,file='t_Ausgabe_TXXmax.txt')
        close(4,status='delete')
        open(5,file='t_Ausgabe_RRmax.txt')
        close(5,status='delete')
        
        open(1,file='t_TNNmin.ps')	!	Lschen von evtl. vorhandenen Ausgabedateien aus... 
        close(1,status='delete')		!	...vorherigen Programmdurchlaeufen.
        open(2,file='t_TNNmax.ps')
        close(2,status='delete')
        open(3,file='t_TXXmin.ps')
        close(3,status='delete')
        open(4,file='t_TXXmax.ps')
        close(4,status='delete')
        open(5,file='t_RRmax.ps')
        close(5,status='delete')
        
        open(1,file='t_TNNmin.log')
        close(1,status='delete')
        open(2,file='t_TNNmax.log')
        close(2,status='delete')
        open(3,file='t_TXXmin.log')
        close(3,status='delete')
        open(4,file='t_TXXmax.log')
        close(4,status='delete')
        open(5,file='t_RRmax.log')
        close(5,status='delete')
        
        read (*,*) abfrage_datei1
                      
        do         
           write(*,'(a28)') 'Zweite Datei einlesen? (j/n)'
           write(*,'(a28)') '****************************'               
           read (*,*) abfrage_weitere1
           if((abfrage_weitere1.eq.'j').or.(abfrage_weitere1.eq.'n')) exit
             write(*,*) 'Falsche Eingabe!'
        end do              
       if(abfrage_weitere1.eq.'j') then
           write(*,'(a34)') 'Bitte zweiten Dateinamen eingeben!'
           write(*,'(a34)') '**********************************' 
           read (*,*) abfrage_datei2
           do 
              write(*,'(a28)') 'Dritte Datei einlesen? (j/n)'
              write(*,'(a28)') '****************************'
              read (*,*) abfrage_weitere2
              if((abfrage_weitere2.eq.'j').or.(abfrage_weitere2.eq.'n')) exit
                 write(*,*) 'Falsche Eingabe!'
           end do
           if(abfrage_weitere2.eq.'j') then
           write(*,'(a34)') 'Bitte dritten Dateinamen eingeben!'
           write(*,'(a34)') '**********************************'
           read (*,*) abfrage_datei3
           end if       
        end if
       
       write(*,*)        
       write(*,'(a28)') 'Anfangsjahr des Datensatzes?'
       write(*,'(a28)') '****************************'
       read(*,*) anfangsjahr
       
        
       open (unit=10, file=abfrage_datei1, status='old',                      & !Bestimmung der Datenanzahl
       form='formatted', action='read', iostat=open_error)			!aus 1. Datei
       read(10,*)
       ii = 1
       do while (.true.)
       read (10, *, iostat = iocheck) dummy_tnn
       if (iocheck .ne. 0) exit
       ii = ii + 1
       end do
       close (unit=10, status='keep')
       ndata1 = ii - 1
       
       if(abfrage_weitere1.eq.'j') then
         open (unit=20, file=abfrage_datei2, status='old',                      & !Bestimmung der Datenanzahl
         form='formatted', action='read', iostat=open_error)			  !aus 2. Datei
         read(20,*)	
         ii = 1
         do while (.true.)
         read (20, *, iostat = iocheck) dummy_txx
         if (iocheck .ne. 0) exit
         ii = ii + 1
         end do
         close (unit=20, status='keep')
         ndata2 = ii - 1
         if(ndata1.ne.ndata2) then						!Fehlerpruefung Datenanzahl.
           write(*,'(a34)') 'Datenanzahl stimmt nicht ueberein!'
           write(*,'(a27)') 'Programm mit Enter beenden!'
           write(*,'(a27)') '***************************'
           pause
           stop
         end if
       end if
       
       if(abfrage_weitere2.eq.'j') then
         open (unit=30, file=abfrage_datei3, status='old',                      & !Bestimmung der Datenanzahl
         form='formatted', action='read', iostat=open_error)			  !aus 3. Datei
         read(30,*)
         ii = 1
         do while (.true.)
         read (30, *, iostat = iocheck) dummy_rr
         if (iocheck .ne. 0) exit
         ii = ii + 1
         end do
         close (unit=30, status='keep')
         ndata3 = ii - 1
         if(ndata1.ne.ndata3) then						!Fehlerpruefung Datenanzahl.
           write(*,'(a34)') 'Datenanzahl stimmt nicht ueberein!'
           write(*,'(a27)') 'Programm mit Enter beenden!'
           write(*,'(a27)') '***************************'
           pause
           stop
         end if
       end if
       
       nyears=ndata1/365							!Bestimmung der Jahresanzahl
       
       write(*,*) 
       write(*,'(a17,i6)') 'Anzahl der Jahre=',nyears
       write(*,*)  
         
         


        do 
        write(*,'(a41)') 'Zeitraum fuer die Summenbildung eingeben:' !Abfrage des Zeitraumes der Berechnung
        write(*,'(a41)') '*****************************************'
        write(*,'(a20)') 'Jahr           :  j1'
        write(*,'(a20)') 'Fruehjahr (MAM):  f1'
        write(*,'(a20)') 'Sommer1   (JJA):  s1'
        write(*,'(a20)') 'Sommer2 (MJJAS):  s2'
        write(*,'(a20)') 'Herbst    (SON):  h1'
        write(*,'(a20)') 'Winter1   (DJF):  w1'
        write(*,'(a20)') 'Winter2 (NDJFM):  w2'

                read (*,*) abfrage

                if((abfrage.eq.'j1').or.(abfrage.eq.'f1').or.(abfrage.eq.'s1') &        !Bei falscher Eingabe wiederholen!
                    .or.(abfrage.eq.'s2').or.(abfrage.eq.'h1').or.             &        !Verlassen der do-Schleife erst bei
                   (abfrage.eq.'w1').or.(abfrage.eq.'w2')) exit                         !richtiger Eingabe.

                write(*,*) 'Zeitraum ist nicht definiert!'
        end do

	!clevel=1-(2*signifikanz)/nyears						!Berechnung des Konfidenzbandes bzw. Konf.-level
	clevel=0.98
        n_sim2=nint(100*2/(one-clevel)) 						!Berechnung der Anzahl der Sim.-schritte
	
!	write(*,'(a72)') 'Folgende Parameter zur Berechnung der Konfidenzbaender werden verwendet:'
!       write(*,'(a28,f15.4)') 'Signifikanz  	   	   s=',signifikanz
!	write(*,'(a28,f15.4)') 'unteres Konfidenzband   low=',(one-clevel)*half
!	write(*,'(a28,f15.4)') 'oberes Konfidenzband    upp=',(one-half*(one-clevel))
	write(*,'(a28,i15)')   'Anzahl der Simulationen   n=',n_sim2
	write(*,*) '                            '
	
	do 
	  write(*,'(a24)') 'n_sim beibehalten? (j/n)'
	  read (*,*) abfrage_sim
	  if((abfrage_sim.eq.'j').or.(abfrage_sim.eq.'n')) exit
	  write(*,*) 'Falsche Eingabe!'
	end do  							
	
	if(abfrage_sim.eq.'j') then		!Abfrage der Anzahl der Simulationen n_sim
	n_sim=n_sim2
	else
	  do 
	  write(*,'(a21)') 'Bitte n_sim eingeben!'
          read (*,*) n_sim3			!Eingabe eines benutzerdefinierten n_sim
          if(n_sim3.gt.0) exit
          write(*,*) 'Falsche Eingabe!'
          end do								
	n_sim=n_sim3
	end if 
	  write(*,*) 
	  write(*,'(a22)') 'Besetzen der Felder...' 
	allocate(sum1_sim(nyears,n_sim))	!Festlegung der Feldgroessen fuer sum1_sim
	allocate(sum2_sim(nyears,n_sim))
	allocate(sum3_sim(nyears,n_sim))
	allocate(sum4_sim(nyears,n_sim))
	allocate(sum5_sim(nyears,n_sim))
	
	allocate(anz1_sim(nyears,n_sim))	!Festlegung der Feldgroessen fuer anz1_sim
	allocate(anz2_sim(nyears,n_sim))
	allocate(anz3_sim(nyears,n_sim))
	allocate(anz4_sim(nyears,n_sim))
	allocate(anz5_sim(nyears,n_sim))
	
	allocate(pro1_sim(nyears,n_sim))	!Festlegung der Feldgroessen fuer pro1_sim
	allocate(pro2_sim(nyears,n_sim))
	allocate(pro3_sim(nyears,n_sim))
	allocate(pro4_sim(nyears,n_sim))
	allocate(pro5_sim(nyears,n_sim))
	
!----Aus Modul variablen-------------------------------------------------
	
        allocate(matrixtnn(1:nyears,1:ndays)) 	
        allocate(matrixtxx(1:nyears,1:ndays)) 	
        allocate(matrixrr(1:nyears,1:ndays))  	

        allocate(sumtnnmin(1:nyears)) 		
        allocate(sumtnnmax(1:nyears)) 
        allocate(sumtxxmin(1:nyears))	        
        allocate(sumtxxmax(1:nyears)) 		
        allocate(sumrrmax(1:nyears))	        

        allocate(anzahltnnmin(1:nyears))	
        allocate(anzahltnnmax(1:nyears))
        allocate(anzahltxxmin(1:nyears))
        allocate(anzahltxxmax(1:nyears))
        allocate(anzahlrrmax(1:nyears))
      
        allocate(produkttnnmin(1:nyears))
        allocate(produkttnnmax(1:nyears))
        allocate(produkttxxmin(1:nyears))
        allocate(produkttxxmax(1:nyears))
        allocate(produktrrmax(1:nyears))
      
        allocate(jahr(1:nyears))
      
!----Aus Modul sim-----------------------------------------------------------

        allocate(r_tn_resample_1_neu(1:nyears,1:ndays))
        allocate(r_tx_resample_1_neu(1:nyears,1:ndays))
        allocate(r_rr_resample_1_neu(1:nyears,1:ndays))
        allocate(r_tn_resample_2_neu(1:nyears,1:ndays))
        allocate(r_tx_resample_2_neu(1:nyears,1:ndays))
        allocate(r_rr_resample_2_neu(1:nyears,1:ndays))
        allocate(r_tn_resample_3_neu(1:nyears,1:ndays))
        allocate(r_tx_resample_3_neu(1:nyears,1:ndays))
        allocate(r_rr_resample_3_neu(1:nyears,1:ndays))
        allocate(r_tn_resample_4_neu(1:nyears,1:ndays))
        allocate(r_tx_resample_4_neu(1:nyears,1:ndays))
        allocate(r_rr_resample_4_neu(1:nyears,1:ndays))
        allocate(r_tn_resample_5_neu(1:nyears,1:ndays))
        allocate(r_tx_resample_5_neu(1:nyears,1:ndays))
        allocate(r_rr_resample_5_neu(1:nyears,1:ndays))
        
!----Aus Modul stats-----------------------------------------------------------

	allocate(e_tnn(1:nyears,1:ndays)) 
	allocate(e_txx(1:nyears,1:ndays))
	allocate(e_rr(1:nyears,1:ndays))
	
	allocate(r_tnn(1:nyears,1:ndays))
	allocate(r_txx(1:nyears,1:ndays)) 
	allocate(r_rr(1:nyears,1:ndays))  

!----Aus Modul boot-----------------------------------------------------------

        allocate(r_tnn_1(1:nyears,1:seventhree))
        allocate(r_txx_1(1:nyears,1:seventhree))
        allocate(r_rr_1(1:nyears,1:seventhree))
        allocate(r_tnn_2(1:nyears,1:seventhree))
        allocate(r_txx_2(1:nyears,1:seventhree))
        allocate(r_rr_2(1:nyears,1:seventhree))
        allocate(r_tnn_3(1:nyears,1:seventhree))
        allocate(r_txx_3(1:nyears,1:seventhree))
        allocate(r_rr_3(1:nyears,1:seventhree))
        allocate(r_tnn_4(1:nyears,1:seventhree))
        allocate(r_txx_4(1:nyears,1:seventhree))
        allocate(r_rr_4(1:nyears,1:seventhree))
        allocate(r_tnn_5(1:nyears,1:seventhree))
        allocate(r_txx_5(1:nyears,1:seventhree))
        allocate(r_rr_5(1:nyears,1:seventhree))
    
        allocate(r_tn_resample_1(1:nyears,1:seventhree))
        allocate(r_tx_resample_1(1:nyears,1:seventhree))
        allocate(r_rr_resample_1(1:nyears,1:seventhree))
        allocate(r_tn_resample_2(1:nyears,1:seventhree))
        allocate(r_tx_resample_2(1:nyears,1:seventhree))
        allocate(r_rr_resample_2(1:nyears,1:seventhree))
        allocate(r_tn_resample_3(1:nyears,1:seventhree))
        allocate(r_tx_resample_3(1:nyears,1:seventhree))
        allocate(r_rr_resample_3(1:nyears,1:seventhree))
        allocate(r_tn_resample_4(1:nyears,1:seventhree))
        allocate(r_tx_resample_4(1:nyears,1:seventhree))
        allocate(r_rr_resample_4(1:nyears,1:seventhree))
        allocate(r_tn_resample_5(1:nyears,1:seventhree))
        allocate(r_tx_resample_5(1:nyears,1:seventhree))
        allocate(r_rr_resample_5(1:nyears,1:seventhree))       

        
        allocate(r_tnn_neu_1(1:nyears*seventhree))
        allocate(r_txx_neu_1(1:nyears*seventhree))
        allocate(r_rr_neu_1(1:nyears*seventhree))
        allocate(r_tnn_neu_2(1:nyears*seventhree))
        allocate(r_txx_neu_2(1:nyears*seventhree))
        allocate(r_rr_neu_2(1:nyears*seventhree))
        allocate(r_tnn_neu_3(1:nyears*seventhree))
        allocate(r_txx_neu_3(1:nyears*seventhree))
        allocate(r_rr_neu_3(1:nyears*seventhree))
        allocate(r_tnn_neu_4(1:nyears*seventhree))
        allocate(r_txx_neu_4(1:nyears*seventhree))
        allocate(r_rr_neu_4(1:nyears*seventhree))
        allocate(r_tnn_neu_5(1:nyears*seventhree))
        allocate(r_txx_neu_5(1:nyears*seventhree))
        allocate(r_rr_neu_5(1:nyears*seventhree))         

 end subroutine start

!
!===================================================================================================
!               subroutine zur Berechnung des Mittelwertes und der Varianz der Temp.- und
!               Niederschlagswerte
subroutine statistik			
        use parameters
        use nrtype
        use variablen
        use stats
        use boot
        use nr, only: ran
        implicit none
                       
        real(sp), dimension(1:ndays) :: sum_vtn
        real(sp), dimension(1:ndays) :: sum_vtx
        real(sp), dimension(1:ndays) :: sum_vrr
        real(sp), dimension(1:ndays) :: sum_matrixtnn
        real(sp), dimension(1:ndays) :: sum_matrixtxx
        real(sp), dimension(1:ndays) :: sum_matrixrr
        integer :: i                                      !Das sind die Laufvariablen     Jahre
      	integer :: j                                      !fuer die do-Schleifen.         Tage
      	integer :: k 
                       
        integer :: idum=1

!------------------------------------------------------------------------------------------
!	Berechnung der Varianz der Originaldaten (tagesweise)
	do j=1,ndays
		do i=1,nyears	
		sum_matrixtnn(j)=sum(matrixtnn(1:nyears,j))
		sum_matrixtxx(j)=sum(matrixtxx(1:nyears,j))
		sum_matrixrr(j)=sum(matrixrr(1:nyears,j))                    
       		end do
        end do
  
      	do j=1,ndays
      		tnn_mittel(j)=sum_matrixtnn(j)/nyears
      		txx_mittel(j)=sum_matrixtxx(j)/nyears
    		rr_mittel(j)=sum_matrixrr(j)/nyears
      	end do      	

      	do j=1,ndays      	
      	sum_vtn(j)=0
      	sum_vtx(j)=0
      	sum_vrr(j)=0      	
      		do i=1,nyears	
		sum_vtn(j)=sum((matrixtnn(1:nyears,j)-tnn_mittel(j))**2)
       	       	sum_vtx(j)=sum((matrixtxx(1:nyears,j)-txx_mittel(j))**2)
       	       	sum_vrr(j)=sum((matrixrr(1:nyears,j)-rr_mittel(j))**2)       		      		
       		end do       		 
        vtnnn(j)=sum_vtn(j)/(nyears-1)			!Varianz der Temperaturwerte (tagesweise, 365 Stueck)
       	vtxxx(j)=sum_vtx(j)/(nyears-1)			!Varianz der Temperaturwerte (tagesweise)
       	vrrr(j)=sum_vrr(j)/(nyears-1) 			!Varianz der Niederschlagswerte (tagesweise)           
       	end do
!	Ende der Berechnung der Varianz der Originaldaten
!-------------------------------------------------------------------------------------------       	
!      Berechnung des Trends des Mittelwertes

!	open(8, file='ausgabe.txt')
	
	do i=1,nyears	      	
           jahr(i)=i+0.0_sp           
        end do   
           	
      	do j=1,ndays					           !Berechnung der zeitl. veraend. Mittelwerte fuer TNN
      	  call fit(jahr(1:nyears),matrixtnn(1:nyears,j),nyears,   &
      	  	a_fit_tnn(j),b_fit_tnn(j),                 	  &
      	  	siga_tnn(j),sigb_tnn(j))      	       	   
      	end do 
      	
      	do j=1,ndays						   !Berechnung der zeitl. veraend. Mittelwerte fuer TXX
      	  call fit(jahr(1:nyears),matrixtxx(1:nyears,j),nyears,   &
      	  	a_fit_txx(j),b_fit_txx(j),	               	  &
      	  	siga_txx(j),sigb_txx(j))   	     	   
      	end do 

      	do j=1,ndays						   !Berechnung der zeitl. veraend. Mittelwerte fuer RR
      	  call medfit(jahr(1:nyears),matrixrr(1:nyears,j),    &
      	  	nyears,a_fit_rr(j),b_fit_rr(j),              		 &
      	  	siga_rr(j))     	   
      	end do 
    	
!Berechnung der Residuen e=x-x(Trend)-----------------------------------------
      		
      	do i=1,nyears						   
      	   do j=1,ndays
      		e_tnn(i,j)=matrixtnn(i,j)-(a_fit_tnn(j)+b_fit_tnn(j)*i)
      		e_txx(i,j)=matrixtxx(i,j)-(a_fit_txx(j)+b_fit_txx(j)*i)
      		e_rr(i,j)=matrixrr(i,j)-(a_fit_rr(j)+b_fit_rr(j)*i)
      	   end do
      	end do 
	
!Berechnung der normierten Residuen r(i,j) und des Markovkoeffizienten a ------ 
        write(*,'(a37)') 'Berechnung der Markovkoeffizienten...'
	call markov
		
!	write(8,'(2(f10.7,1x))') (a_fit_tnn(j),b_fit_tnn(j),j=1,365)

        
!Berechnung der Blocklaenge des Blockbootstraps  ------------------------------      
        write(*,'(a30)') 'Berechnung der Blocklaengen...' 
        write(*,*)      
        call blocklaenge
        
        if(abfrage_weitere1.eq.'n') then
        write(*,*) 'Jahreszeit 1 a_markov    =',a_markov_tnn_1
        write(*,*) 'Jahreszeit 1 Blockleangen=',l_mbb_tnn_1                
	write(*,*)
	write(*,*) 'Jahreszeit 2 a_markov    =',a_markov_tnn_2
        write(*,*) 'Jahreszeit 2 Blockleangen=',l_mbb_tnn_2                
	write(*,*) 
	write(*,*) 'Jahreszeit 3 a_markov    =',a_markov_tnn_3
        write(*,*) 'Jahreszeit 3 Blockleangen=',l_mbb_tnn_3                
	write(*,*) 
	write(*,*) 'Jahreszeit 4 a_markov    =',a_markov_tnn_4
        write(*,*) 'Jahreszeit 4 Blockleangen=',l_mbb_tnn_4                
	write(*,*) 
	write(*,*) 'Jahreszeit 5 a_markov    =',a_markov_tnn_5
        write(*,*) 'Jahreszeit 5 Blockleangen=',l_mbb_tnn_5                
	write(*,*)
	
	else
	
	if(abfrage_weitere2.eq.'n') then
	write(*,*) 'Jahreszeit 1 a_markov    =',a_markov_tnn_1, a_markov_txx_1
        write(*,*) 'Jahreszeit 1 Blockleangen=',l_mbb_tnn_1, l_mbb_txx_1               
	write(*,*)
	write(*,*) 'Jahreszeit 2 a_markov    =',a_markov_tnn_2, a_markov_txx_2
        write(*,*) 'Jahreszeit 2 Blockleangen=',l_mbb_tnn_2, l_mbb_txx_2                
	write(*,*) 
	write(*,*) 'Jahreszeit 3 a_markov    =',a_markov_tnn_3, a_markov_txx_3
        write(*,*) 'Jahreszeit 3 Blockleangen=',l_mbb_tnn_3, l_mbb_txx_3               
	write(*,*) 
	write(*,*) 'Jahreszeit 4 a_markov    =',a_markov_tnn_4, a_markov_txx_4
        write(*,*) 'Jahreszeit 4 Blockleangen=',l_mbb_tnn_4, l_mbb_txx_4                
	write(*,*) 
	write(*,*) 'Jahreszeit 5 a_markov    =',a_markov_tnn_5, a_markov_txx_5
        write(*,*) 'Jahreszeit 5 Blockleangen=',l_mbb_tnn_5, l_mbb_txx_5                
	write(*,*)
	end if
	
	if(abfrage_weitere2.eq.'j') then
	write(*,*) 'Jahreszeit 1 a_markov    =',a_markov_tnn_1, a_markov_txx_1, a_markov_rr_1
        write(*,*) 'Jahreszeit 1 Blockleangen=',l_mbb_tnn_1, l_mbb_txx_1, l_mbb_rr_1                
	write(*,*)
	write(*,*) 'Jahreszeit 2 a_markov    =',a_markov_tnn_2, a_markov_txx_2, a_markov_rr_2
        write(*,*) 'Jahreszeit 2 Blockleangen=',l_mbb_tnn_2, l_mbb_txx_2, l_mbb_rr_2                
	write(*,*) 
	write(*,*) 'Jahreszeit 3 a_markov    =',a_markov_tnn_3, a_markov_txx_3, a_markov_rr_3
        write(*,*) 'Jahreszeit 3 Blockleangen=',l_mbb_tnn_3, l_mbb_txx_3, l_mbb_rr_3                
	write(*,*) 
	write(*,*) 'Jahreszeit 4 a_markov    =',a_markov_tnn_4, a_markov_txx_4, a_markov_rr_4
        write(*,*) 'Jahreszeit 4 Blockleangen=',l_mbb_tnn_4, l_mbb_txx_4, l_mbb_rr_4                
	write(*,*) 
	write(*,*) 'Jahreszeit 5 a_markov    =',a_markov_tnn_5, a_markov_txx_5, a_markov_rr_5
        write(*,*) 'Jahreszeit 5 Blockleangen=',l_mbb_tnn_5, l_mbb_txx_5, l_mbb_rr_5                
	write(*,*)
	end if
	
	end if    
	
	do 
	  write(*,'(a31)') 'Blocklaengen beibehalten? (j/n)'
	  write(*,'(a31)') '*******************************'
	  read (*,*) abfrage_block
	  if((abfrage_block.eq.'j').or.(abfrage_block.eq.'n')) exit
	  write(*,*) 'Falsche Eingabe!'
	end do    
	
	if(abfrage_block.eq.'n') then	
	do 
	  write(*,'(a23)') 'Bitte L_Block eingeben!'
          read (*,*) l_block				!Eingabe eines benutzerdefinierten L_Block
          if(l_block.gt.0) exit
          write(*,*) 'Falsche Eingabe!'
        end do								
	
        l_mbb_tnn_1=l_block 				!Festlegung des benutzerdefinierten L_Block
        l_mbb_txx_1=l_block
        l_mbb_rr_1=l_block
        l_mbb_tnn_2=l_block
        l_mbb_txx_2=l_block
        l_mbb_rr_2=l_block
        l_mbb_tnn_3=l_block
        l_mbb_txx_3=l_block
        l_mbb_rr_3=l_block
        l_mbb_tnn_4=l_block
        l_mbb_txx_4=l_block
        l_mbb_rr_4=l_block
        l_mbb_tnn_5=l_block
        l_mbb_txx_5=l_block
        l_mbb_rr_5=l_block
        end if 	
	
!	write(8,'(f5.1)') r_pack_tnn 
        
!  	close(8)
999 	format(113(1x,f7.1))
end subroutine statistik


